# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .add_method_response import AddMethodResponse
    from .add_method_response_response_data import AddMethodResponseResponseData
    from .convert_token import ConvertToken
    from .create_anonymous import CreateAnonymous
    from .get_method_response import GetMethodResponse
    from .get_method_response_response_data import GetMethodResponseResponseData
    from .get_method_response_response_data_customers_item import GetMethodResponseResponseDataCustomersItem
    from .request_token_storage import RequestTokenStorage
    from .request_token_storage_payment_method import RequestTokenStoragePaymentMethod
    from .temporary import Temporary
    from .tokenize_ach import TokenizeAch
    from .tokenize_card import TokenizeCard
_dynamic_imports: typing.Dict[str, str] = {
    "AddMethodResponse": ".add_method_response",
    "AddMethodResponseResponseData": ".add_method_response_response_data",
    "ConvertToken": ".convert_token",
    "CreateAnonymous": ".create_anonymous",
    "GetMethodResponse": ".get_method_response",
    "GetMethodResponseResponseData": ".get_method_response_response_data",
    "GetMethodResponseResponseDataCustomersItem": ".get_method_response_response_data_customers_item",
    "RequestTokenStorage": ".request_token_storage",
    "RequestTokenStoragePaymentMethod": ".request_token_storage_payment_method",
    "Temporary": ".temporary",
    "TokenizeAch": ".tokenize_ach",
    "TokenizeCard": ".tokenize_card",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AddMethodResponse",
    "AddMethodResponseResponseData",
    "ConvertToken",
    "CreateAnonymous",
    "GetMethodResponse",
    "GetMethodResponseResponseData",
    "GetMethodResponseResponseDataCustomersItem",
    "RequestTokenStorage",
    "RequestTokenStoragePaymentMethod",
    "Temporary",
    "TokenizeAch",
    "TokenizeCard",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.bill_data import BillData
from ...types.bill_options import BillOptions
from ...types.payor_data_request import PayorDataRequest


class InvoiceDataRequest(UniversalBaseModel):
    customer_data: typing_extensions.Annotated[
        typing.Optional[PayorDataRequest], FieldMetadata(alias="customerData")
    ] = pydantic.Field(default=None)
    """
    Object describing the customer/payor. Required for POST requests. Which fields are required depends on the paypoint's custom identifier settings. 
    """

    invoice_data: typing_extensions.Annotated[typing.Optional[BillData], FieldMetadata(alias="invoiceData")] = (
        pydantic.Field(default=None)
    )
    """
    Object describing the invoice. Required for POST requests.
    """

    scheduled_options: typing_extensions.Annotated[
        typing.Optional[BillOptions], FieldMetadata(alias="scheduledOptions")
    ] = pydantic.Field(default=None)
    """
    Object with options for scheduled invoices.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .a_section import ASection
    from .accept_oauth import AcceptOauth
    from .accept_register import AcceptRegister
    from .account_number import AccountNumber
    from .accountexp import Accountexp
    from .accountid import Accountid
    from .accounting_field import AccountingField
    from .accounttype import Accounttype
    from .accountzip import Accountzip
    from .ach import Ach
    from .ach_absorb_section import AchAbsorbSection
    from .ach_acceptance_element import AchAcceptanceElement
    from .ach_fee_section import AchFeeSection
    from .ach_holder import AchHolder
    from .ach_holder_type import AchHolderType
    from .ach_link_types import AchLinkTypes
    from .ach_pass_through_section import AchPassThroughSection
    from .ach_payment_method import AchPaymentMethod
    from .ach_sec_code import AchSecCode
    from .ach_section import AchSection
    from .ach_service import AchService
    from .ach_setup import AchSetup
    from .ach_types import AchTypes
    from .ach_types_pass import AchTypesPass
    from .ach_types_tiers import AchTypesTiers
    from .ach_validation import AchValidation
    from .achaccount import Achaccount
    from .achaccounttype import Achaccounttype
    from .achrouting import Achrouting
    from .add_payment_method_domain_api_response import AddPaymentMethodDomainApiResponse
    from .additional_data import AdditionalData
    from .additional_data_map import AdditionalDataMap
    from .additional_data_string import AdditionalDataString
    from .address_addtl_nullable import AddressAddtlNullable
    from .address_nullable import AddressNullable
    from .amount_element import AmountElement
    from .annualrevenue import Annualrevenue
    from .app_id import AppId
    from .apple_pay_data import ApplePayData
    from .apple_pay_id import ApplePayId
    from .apple_pay_metadata import ApplePayMetadata
    from .apple_pay_organization_update_data import ApplePayOrganizationUpdateData
    from .apple_pay_paypoint_registration_data import ApplePayPaypointRegistrationData
    from .apple_pay_status_data import ApplePayStatusData
    from .apple_pay_type import ApplePayType
    from .apple_wallet_data import AppleWalletData
    from .application_data import ApplicationData
    from .application_data_managed import ApplicationDataManaged
    from .application_data_managed_contacts_item import ApplicationDataManagedContactsItem
    from .application_data_managed_ownership_item import ApplicationDataManagedOwnershipItem
    from .application_data_odp import ApplicationDataOdp
    from .application_data_odp_contacts_item import ApplicationDataOdpContactsItem
    from .application_data_odp_ownership_item import ApplicationDataOdpOwnershipItem
    from .application_data_pay_in import ApplicationDataPayIn
    from .application_data_pay_in_bank_data import ApplicationDataPayInBankData
    from .application_data_pay_in_contacts_item import ApplicationDataPayInContactsItem
    from .application_data_pay_in_ownership_item import ApplicationDataPayInOwnershipItem
    from .application_data_pay_in_services import ApplicationDataPayInServices
    from .application_data_pay_in_services_ach import ApplicationDataPayInServicesAch
    from .application_data_pay_in_services_card import ApplicationDataPayInServicesCard
    from .application_details_record import ApplicationDetailsRecord
    from .application_details_record_messages_item import ApplicationDetailsRecordMessagesItem
    from .application_query_record import ApplicationQueryRecord
    from .associated_vendor import AssociatedVendor
    from .attachments import Attachments
    from .attestation_date import AttestationDate
    from .authcode import Authcode
    from .auto_element import AutoElement
    from .avgmonthly import Avgmonthly
    from .avgticketamt import Avgticketamt
    from .avsresponsetext import Avsresponsetext
    from .b_address import BAddress
    from .b_details import BDetails
    from .b_section import BSection
    from .baddress_1 import Baddress1
    from .baddress_2 import Baddress2
    from .bank import Bank
    from .bank_account_function import BankAccountFunction
    from .bank_account_holder_name import BankAccountHolderName
    from .bank_account_holder_type import BankAccountHolderType
    from .bank_data import BankData
    from .bank_name import BankName
    from .bank_nickname import BankNickname
    from .bank_section import BankSection
    from .basic_table import BasicTable
    from .basic_template_element import BasicTemplateElement
    from .batch_number import BatchNumber
    from .batch_summary import BatchSummary
    from .bcity import Bcity
    from .bcountry import Bcountry
    from .bill_approvals import BillApprovals
    from .bill_data import BillData
    from .bill_data_payment_terms import BillDataPaymentTerms
    from .bill_detail_response import BillDetailResponse
    from .bill_details_response import BillDetailsResponse
    from .bill_events import BillEvents
    from .bill_id import BillId
    from .bill_item import BillItem
    from .bill_options import BillOptions
    from .bill_pay_out_data import BillPayOutData
    from .bill_pay_out_data_request import BillPayOutDataRequest
    from .bill_query_record_2 import BillQueryRecord2
    from .bill_query_record_2_bill_approvals_item import BillQueryRecord2BillApprovalsItem
    from .bill_query_record_2_payment_method import BillQueryRecord2PaymentMethod
    from .bill_query_response import BillQueryResponse
    from .bill_query_response_summary import BillQueryResponseSummary
    from .billing_address_addtl_nullable import BillingAddressAddtlNullable
    from .billing_address_nullable import BillingAddressNullable
    from .billing_city_nullable import BillingCityNullable
    from .billing_country_nullable import BillingCountryNullable
    from .billing_data import BillingData
    from .billing_data_response import BillingDataResponse
    from .billing_fee_detail import BillingFeeDetail
    from .billing_state_nullable import BillingStateNullable
    from .billing_zip import BillingZip
    from .billitems import Billitems
    from .billstatus import Billstatus
    from .bin_data import BinData
    from .binperson import Binperson
    from .binphone import Binphone
    from .binweb import Binweb
    from .bnk import Bnk
    from .boarding_application_attachments import BoardingApplicationAttachments
    from .boarding_average_bill_size import BoardingAverageBillSize
    from .boarding_avg_monthly_bill import BoardingAvgMonthlyBill
    from .boarding_business_fax import BoardingBusinessFax
    from .boarding_business_phone import BoardingBusinessPhone
    from .boarding_id import BoardingId
    from .boarding_link_api_response import BoardingLinkApiResponse
    from .boarding_link_id import BoardingLinkId
    from .boarding_link_query_record import BoardingLinkQueryRecord
    from .boarding_query_links import BoardingQueryLinks
    from .boarding_status import BoardingStatus
    from .bphone import Bphone
    from .bstate import Bstate
    from .bsummary import Bsummary
    from .builder_data import BuilderData
    from .business_section import BusinessSection
    from .busstartdate import Busstartdate
    from .button_element import ButtonElement
    from .button_element_size import ButtonElementSize
    from .bzip import Bzip
    from .c_list import CList
    from .card_acceptance_element import CardAcceptanceElement
    from .card_fee_section import CardFeeSection
    from .card_flat_section import CardFlatSection
    from .card_icp_section import CardIcpSection
    from .card_link_types import CardLinkTypes
    from .card_pass_through_section import CardPassThroughSection
    from .card_section import CardSection
    from .card_service import CardService
    from .card_setup import CardSetup
    from .card_type import CardType
    from .card_type_pass import CardTypePass
    from .card_types import CardTypes
    from .cardcvv import Cardcvv
    from .cardexp import Cardexp
    from .cardholder import Cardholder
    from .cardnumber import Cardnumber
    from .cardzip import Cardzip
    from .cascade import Cascade
    from .cascade_job_details import CascadeJobDetails
    from .cash import Cash
    from .category import Category
    from .chargeback_id import ChargebackId
    from .check import Check
    from .city_nullable import CityNullable
    from .cloud_query_api_response import CloudQueryApiResponse
    from .comments import Comments
    from .configure_apple_pay_organization_api_response import ConfigureApplePayOrganizationApiResponse
    from .configure_apple_paypoint_api_response import ConfigureApplePaypointApiResponse
    from .configure_google_paypoint_api_response import ConfigureGooglePaypointApiResponse
    from .contact_element import ContactElement
    from .contacts import Contacts
    from .contacts_field import ContactsField
    from .contacts_response import ContactsResponse
    from .country_nullable import CountryNullable
    from .created_at import CreatedAt
    from .customer_data import CustomerData
    from .customer_id import CustomerId
    from .customer_number_nullable import CustomerNumberNullable
    from .customer_query_records import CustomerQueryRecords
    from .customer_query_records_customer_consent import CustomerQueryRecordsCustomerConsent
    from .customer_query_records_customer_consent_e_communication import (
        CustomerQueryRecordsCustomerConsentECommunication,
    )
    from .customer_query_records_customer_consent_sms import CustomerQueryRecordsCustomerConsentSms
    from .customer_status import CustomerStatus
    from .customer_summary_record import CustomerSummaryRecord
    from .customeridtrans import Customeridtrans
    from .cvvresponsetext import Cvvresponsetext
    from .d_section import DSection
    from .datenullable import Datenullable
    from .datetime_nullable import DatetimeNullable
    from .dbaname import Dbaname
    from .deposit_date import DepositDate
    from .descriptor import Descriptor
    from .device import Device
    from .device_id import DeviceId
    from .discount import Discount
    from .display_property import DisplayProperty
    from .document_section import DocumentSection
    from .document_section_terms_and_conditions import DocumentSectionTermsAndConditions
    from .document_section_terms_and_conditions_tc_links_item import DocumentSectionTermsAndConditionsTcLinksItem
    from .documents_ref import DocumentsRef
    from .domain_name import DomainName
    from .duty_amount import DutyAmount
    from .ein import Ein
    from .element import Element
    from .email import Email
    from .enabled import Enabled
    from .enrollment_status import EnrollmentStatus
    from .entity_id import EntityId
    from .entity_type import EntityType
    from .entry import Entry
    from .entry_attributes import EntryAttributes
    from .entrypage_id import EntrypageId
    from .entrypointfield import Entrypointfield
    from .expected_deposit_date import ExpectedDepositDate
    from .expected_processing_date_time import ExpectedProcessingDateTime
    from .export_format import ExportFormat
    from .external_paypoint_id import ExternalPaypointId
    from .external_processor_information import ExternalProcessorInformation
    from .fax_number import FaxNumber
    from .fee_amount import FeeAmount
    from .file import File
    from .file_content import FileContent
    from .file_content_ftype import FileContentFtype
    from .finishtype import Finishtype
    from .force_customer_creation import ForceCustomerCreation
    from .freight_amount import FreightAmount
    from .frequency import Frequency
    from .frequency_list import FrequencyList
    from .frequencynotification import Frequencynotification
    from .gatewayfield import Gatewayfield
    from .general_events import GeneralEvents
    from .google_pay_data import GooglePayData
    from .google_pay_metadata import GooglePayMetadata
    from .google_pay_paypoint_registration_data import GooglePayPaypointRegistrationData
    from .google_pay_status_data import GooglePayStatusData
    from .google_wallet_data import GoogleWalletData
    from .has_vcard_transactions import HasVcardTransactions
    from .header_element import HeaderElement
    from .highticketamt import Highticketamt
    from .holdername import Holdername
    from .idempotency_key import IdempotencyKey
    from .identifierfields import Identifierfields
    from .idpaypoint import Idpaypoint
    from .initiator import Initiator
    from .instrument import Instrument
    from .internal_reference_id import InternalReferenceId
    from .invoice_amount import InvoiceAmount
    from .invoice_element import InvoiceElement
    from .invoice_number import InvoiceNumber
    from .invoice_type import InvoiceType
    from .invoicestatus import Invoicestatus
    from .ip_address import IpAddress
    from .is_enabled import IsEnabled
    from .is_root import IsRoot
    from .is_same_day_ach import IsSameDayAch
    from .is_success import IsSuccess
    from .item_commodity_code import ItemCommodityCode
    from .item_description import ItemDescription
    from .item_product_code import ItemProductCode
    from .item_product_name import ItemProductName
    from .item_unitof_measure import ItemUnitofMeasure
    from .job_id import JobId
    from .job_status import JobStatus
    from .key_value import KeyValue
    from .key_value_duo import KeyValueDuo
    from .label_element import LabelElement
    from .language import Language
    from .last_modified import LastModified
    from .legalname import Legalname
    from .license import License
    from .licensestate import Licensestate
    from .line_item import LineItem
    from .line_item_query_record import LineItemQueryRecord
    from .link_data import LinkData
    from .link_row import LinkRow
    from .location_code import LocationCode
    from .maddress import Maddress
    from .maddress_1 import Maddress1
    from .maskedaccount import Maskedaccount
    from .mcc import Mcc
    from .mcity import Mcity
    from .mcountry import Mcountry
    from .method_element import MethodElement
    from .method_element_settings import MethodElementSettings
    from .method_element_settings_apple_pay import MethodElementSettingsApplePay
    from .method_element_settings_apple_pay_button_style import MethodElementSettingsApplePayButtonStyle
    from .method_element_settings_apple_pay_button_type import MethodElementSettingsApplePayButtonType
    from .method_element_settings_apple_pay_language import MethodElementSettingsApplePayLanguage
    from .method_query_records import MethodQueryRecords
    from .method_reference_id import MethodReferenceId
    from .methodall import Methodall
    from .methodnotification import Methodnotification
    from .methods_list import MethodsList
    from .mfa import Mfa
    from .mfa_data import MfaData
    from .mfa_mode import MfaMode
    from .mfa_validation_code import MfaValidationCode
    from .mstate import Mstate
    from .mzip import Mzip
    from .name_user import NameUser
    from .net_amountstring import NetAmountstring
    from .netamountnullable import Netamountnullable
    from .note_element import NoteElement
    from .notification_content import NotificationContent
    from .notification_content_event_type import NotificationContentEventType
    from .notification_content_file_format import NotificationContentFileFormat
    from .notification_content_report_name import NotificationContentReportName
    from .notification_id import NotificationId
    from .notification_query_record import NotificationQueryRecord
    from .notification_report_request import NotificationReportRequest
    from .notification_report_request_content import NotificationReportRequestContent
    from .notification_report_request_content_file_format import NotificationReportRequestContentFileFormat
    from .notification_report_request_content_report_name import NotificationReportRequestContentReportName
    from .notification_report_request_frequency import NotificationReportRequestFrequency
    from .notification_report_request_method import NotificationReportRequestMethod
    from .notification_standard_request import NotificationStandardRequest
    from .notification_standard_request_content import NotificationStandardRequestContent
    from .notification_standard_request_content_event_type import NotificationStandardRequestContentEventType
    from .notification_standard_request_frequency import NotificationStandardRequestFrequency
    from .notification_standard_request_method import NotificationStandardRequestMethod
    from .o_list import OList
    from .o_section import OSection
    from .odp_setup import OdpSetup
    from .odp_setup_processing_region import OdpSetupProcessingRegion
    from .operation import Operation
    from .optin_status import OptinStatus
    from .order import Order
    from .order_id import OrderId
    from .orderdescription import Orderdescription
    from .org_data import OrgData
    from .org_parent_id import OrgParentId
    from .org_parent_name import OrgParentName
    from .org_scope import OrgScope
    from .org_x_scope import OrgXScope
    from .orgaddress import Orgaddress
    from .organization_id import OrganizationId
    from .organization_query_record import OrganizationQueryRecord
    from .organization_query_record_services_item import OrganizationQueryRecordServicesItem
    from .organization_updates import OrganizationUpdates
    from .orgcity import Orgcity
    from .orgcountry import Orgcountry
    from .orgentryname import Orgentryname
    from .orgid import Orgid
    from .orgidstring import Orgidstring
    from .orgname import Orgname
    from .orgstate import Orgstate
    from .orgtimezone import Orgtimezone
    from .orgtype import Orgtype
    from .orgwebsite import Orgwebsite
    from .orgzip import Orgzip
    from .own_type import OwnType
    from .owner_entity_id import OwnerEntityId
    from .owner_entity_type import OwnerEntityType
    from .ownerid import Ownerid
    from .owners import Owners
    from .owners_section import OwnersSection
    from .ownership import Ownership
    from .ownertype import Ownertype
    from .p_section import PSection
    from .page_content import PageContent
    from .page_element import PageElement
    from .page_identifier import PageIdentifier
    from .page_setting import PageSetting
    from .pagelink_setting import PagelinkSetting
    from .pagesize import Pagesize
    from .pair_files import PairFiles
    from .pay_category import PayCategory
    from .pay_method_ach import PayMethodAch
    from .pay_method_body_all_fields import PayMethodBodyAllFields
    from .pay_method_cloud import PayMethodCloud
    from .pay_method_credit import PayMethodCredit
    from .pay_method_stored_method import PayMethodStoredMethod
    from .pay_method_stored_method_method import PayMethodStoredMethodMethod
    from .payabli_api_response import PayabliApiResponse
    from .payabli_api_response_0 import PayabliApiResponse0
    from .payabli_api_response_00 import PayabliApiResponse00
    from .payabli_api_response_0000 import PayabliApiResponse0000
    from .payabli_api_response_00_responsedatanonobject import PayabliApiResponse00Responsedatanonobject
    from .payabli_api_response_0_response_data import PayabliApiResponse0ResponseData
    from .payabli_api_response_6 import PayabliApiResponse6
    from .payabli_api_response_customer_query import PayabliApiResponseCustomerQuery
    from .payabli_api_response_error_400 import PayabliApiResponseError400
    from .payabli_api_response_error_400_response_data import PayabliApiResponseError400ResponseData
    from .payabli_api_response_generic_2_part import PayabliApiResponseGeneric2Part
    from .payabli_api_response_import import PayabliApiResponseImport
    from .payabli_api_response_import_response_data import PayabliApiResponseImportResponseData
    from .payabli_api_response_mfa_basic import PayabliApiResponseMfaBasic
    from .payabli_api_response_notifications import PayabliApiResponseNotifications
    from .payabli_api_response_notifications_response_data import PayabliApiResponseNotificationsResponseData
    from .payabli_api_response_paylinks import PayabliApiResponsePaylinks
    from .payabli_api_response_paymethod_delete import PayabliApiResponsePaymethodDelete
    from .payabli_api_response_paymethod_delete_response_data import PayabliApiResponsePaymethodDeleteResponseData
    from .payabli_api_response_template_id import PayabliApiResponseTemplateId
    from .payabli_api_response_user_mfa import PayabliApiResponseUserMfa
    from .payabli_api_response_vendors import PayabliApiResponseVendors
    from .payabli_credentials import PayabliCredentials
    from .payabli_credentials_pascal import PayabliCredentialsPascal
    from .payabli_pages import PayabliPages
    from .payee_name import PayeeName
    from .paylink_id import PaylinkId
    from .payment_categories import PaymentCategories
    from .payment_detail import PaymentDetail
    from .payment_detail_credit import PaymentDetailCredit
    from .payment_id_string import PaymentIdString
    from .payment_method import PaymentMethod
    from .payment_method_domain_api_response import PaymentMethodDomainApiResponse
    from .payment_method_domain_general_response import PaymentMethodDomainGeneralResponse
    from .payment_method_domain_id import PaymentMethodDomainId
    from .payment_trans_status_description import PaymentTransStatusDescription
    from .paymentid import Paymentid
    from .payor_data_request import PayorDataRequest
    from .payor_data_response import PayorDataResponse
    from .payor_element import PayorElement
    from .payor_fields import PayorFields
    from .payor_id import PayorId
    from .payout_average_monthly_volume import PayoutAverageMonthlyVolume
    from .payout_average_ticket_limit import PayoutAverageTicketLimit
    from .payout_credit_limit import PayoutCreditLimit
    from .payout_gateway_connector import PayoutGatewayConnector
    from .payout_high_ticket_amount import PayoutHighTicketAmount
    from .payout_program import PayoutProgram
    from .paypoint_data import PaypointData
    from .paypoint_entry_config import PaypointEntryConfig
    from .paypoint_id import PaypointId
    from .paypoint_name import PaypointName
    from .paypoint_summary import PaypointSummary
    from .paypointstatus import Paypointstatus
    from .pci_attestation import PciAttestation
    from .pending_fee_amount import PendingFeeAmount
    from .phone_number import PhoneNumber
    from .poi_device import PoiDevice
    from .policy_id import PolicyId
    from .pos_col import PosCol
    from .pos_row import PosRow
    from .processing_section import ProcessingSection
    from .purchase_order import PurchaseOrder
    from .push_pay_link_request import PushPayLinkRequest, PushPayLinkRequest_Email, PushPayLinkRequest_Sms
    from .push_pay_link_request_email import PushPayLinkRequestEmail
    from .push_pay_link_request_sms import PushPayLinkRequestSms
    from .query_batches_out_response import QueryBatchesOutResponse
    from .query_batches_out_response_records_item import QueryBatchesOutResponseRecordsItem
    from .query_boarding_apps_list_response import QueryBoardingAppsListResponse
    from .query_boarding_links_response import QueryBoardingLinksResponse
    from .query_boarding_links_response_records_item import QueryBoardingLinksResponseRecordsItem
    from .query_c_fee_transaction import QueryCFeeTransaction
    from .query_chargebacks_response import QueryChargebacksResponse
    from .query_chargebacks_response_records_item import QueryChargebacksResponseRecordsItem
    from .query_customer_response import QueryCustomerResponse
    from .query_entrypoint_response import QueryEntrypointResponse
    from .query_entrypoint_response_records_item import QueryEntrypointResponseRecordsItem
    from .query_payment_data import QueryPaymentData
    from .query_payout_transaction import QueryPayoutTransaction
    from .query_payout_transaction_records_item import QueryPayoutTransactionRecordsItem
    from .query_payout_transaction_records_item_payment_data import QueryPayoutTransactionRecordsItemPaymentData
    from .query_payout_transaction_summary import QueryPayoutTransactionSummary
    from .query_response import QueryResponse
    from .query_response_data import QueryResponseData
    from .query_response_items import QueryResponseItems
    from .query_response_items_records_item import QueryResponseItemsRecordsItem
    from .query_response_notification_reports import QueryResponseNotificationReports
    from .query_response_notification_reports_records_item import QueryResponseNotificationReportsRecordsItem
    from .query_response_notifications import QueryResponseNotifications
    from .query_response_notifications_records_item import QueryResponseNotificationsRecordsItem
    from .query_response_settlements import QueryResponseSettlements
    from .query_response_settlements_records_item import QueryResponseSettlementsRecordsItem
    from .query_response_settlements_summary import QueryResponseSettlementsSummary
    from .query_response_transactions import QueryResponseTransactions
    from .query_response_vendors import QueryResponseVendors
    from .query_subscription_response import QuerySubscriptionResponse
    from .query_summary import QuerySummary
    from .query_summary_no_amt import QuerySummaryNoAmt
    from .query_transaction_events import QueryTransactionEvents
    from .query_transaction_events_event_data import QueryTransactionEventsEventData
    from .query_transaction_payor_data import QueryTransactionPayorData
    from .query_user_response import QueryUserResponse
    from .read_only import ReadOnly
    from .receipt_content import ReceiptContent
    from .recipient_email_notification import RecipientEmailNotification
    from .reference_name import ReferenceName
    from .reference_template_id import ReferenceTemplateId
    from .referenceidtrans import Referenceidtrans
    from .refund_detail import RefundDetail
    from .refund_id import RefundId
    from .remit_email import RemitEmail
    from .remitaddress_1 import Remitaddress1
    from .remitaddress_2 import Remitaddress2
    from .remitcity import Remitcity
    from .remitcountry import Remitcountry
    from .remitstate import Remitstate
    from .remitzip import Remitzip
    from .rep_code import RepCode
    from .rep_name import RepName
    from .rep_office import RepOffice
    from .reply_to_email import ReplyToEmail
    from .replyby import Replyby
    from .required_element import RequiredElement
    from .response_text import ResponseText
    from .responsecode import Responsecode
    from .responsedata import Responsedata
    from .responsedatanonobject import Responsedatanonobject
    from .result_code import ResultCode
    from .resulttext import Resulttext
    from .resumable import Resumable
    from .retrieval_id import RetrievalId
    from .returned_id import ReturnedId
    from .risk_action import RiskAction
    from .risk_action_code import RiskActionCode
    from .risk_flagged import RiskFlagged
    from .risk_flagged_on import RiskFlaggedOn
    from .risk_reason import RiskReason
    from .risk_status import RiskStatus
    from .room_id_not_in_use import RoomIdNotInUse
    from .routing_account import RoutingAccount
    from .s_section import SSection
    from .sales_code import SalesCode
    from .sales_section import SalesSection
    from .save_if_success import SaveIfSuccess
    from .schedule_detail import ScheduleDetail
    from .schedule_id import ScheduleId
    from .sequence import Sequence
    from .service_cost import ServiceCost
    from .services import Services
    from .services_section import ServicesSection
    from .setting_element import SettingElement
    from .settings_query_record import SettingsQueryRecord
    from .settlement_status import SettlementStatus
    from .settlement_status_payout import SettlementStatusPayout
    from .shipping_from_zip import ShippingFromZip
    from .shippingaddress import Shippingaddress
    from .shippingaddressadditional import Shippingaddressadditional
    from .shippingcity import Shippingcity
    from .shippingcountry import Shippingcountry
    from .shippingstate import Shippingstate
    from .shippingzip import Shippingzip
    from .sign_date import SignDate
    from .signaturedata import Signaturedata
    from .signed_document_reference import SignedDocumentReference
    from .signer_acceptance import SignerAcceptance
    from .signer_address_1 import SignerAddress1
    from .signer_city import SignerCity
    from .signer_country import SignerCountry
    from .signer_data import SignerData
    from .signer_data_request import SignerDataRequest
    from .signer_dob import SignerDob
    from .signer_name import SignerName
    from .signer_phone import SignerPhone
    from .signer_section import SignerSection
    from .signer_ssn import SignerSsn
    from .signer_state import SignerState
    from .signer_zip import SignerZip
    from .signeraddress import Signeraddress
    from .source import Source
    from .split_funding import SplitFunding
    from .split_funding_content import SplitFundingContent
    from .split_funding_refund_content import SplitFundingRefundContent
    from .state_nullable import StateNullable
    from .statusnotification import Statusnotification
    from .stored_method_usage_type import StoredMethodUsageType
    from .storedmethodid import Storedmethodid
    from .sub_footer import SubFooter
    from .sub_header import SubHeader
    from .subdomain import Subdomain
    from .subscription_query_records import SubscriptionQueryRecords
    from .subscriptionid import Subscriptionid
    from .summary_commodity_code import SummaryCommodityCode
    from .summary_org import SummaryOrg
    from .target import Target
    from .tax import Tax
    from .taxfillname import Taxfillname
    from .template_additional_data_field import TemplateAdditionalDataField
    from .template_additional_data_section import TemplateAdditionalDataSection
    from .template_code import TemplateCode
    from .template_content import TemplateContent
    from .template_content_response import TemplateContentResponse
    from .template_data import TemplateData
    from .template_element import TemplateElement
    from .template_id import TemplateId
    from .template_name import TemplateName
    from .template_query_record import TemplateQueryRecord
    from .template_query_response import TemplateQueryResponse
    from .terms import Terms
    from .terms_conditions import TermsConditions
    from .ticketamt import Ticketamt
    from .tier_item import TierItem
    from .tier_item_pass import TierItemPass
    from .timezone import Timezone
    from .totalpages import Totalpages
    from .totalrecords import Totalrecords
    from .trans_status import TransStatus
    from .transaction_out_query_record import TransactionOutQueryRecord
    from .transaction_query_records import TransactionQueryRecords
    from .transaction_time import TransactionTime
    from .transfer import Transfer
    from .transfer_bank_account import TransferBankAccount
    from .transfer_identifier import TransferIdentifier
    from .transfer_message import TransferMessage
    from .transfer_message_properties import TransferMessageProperties
    from .transfer_query_response import TransferQueryResponse
    from .transfer_summary import TransferSummary
    from .type_account import TypeAccount
    from .under_writing_method import UnderWritingMethod
    from .underwriting_data import UnderwritingData
    from .underwriting_data_response import UnderwritingDataResponse
    from .user_data import UserData
    from .user_query_record import UserQueryRecord
    from .usr_access import UsrAccess
    from .usr_status import UsrStatus
    from .v_card_query_response import VCardQueryResponse
    from .v_card_record import VCardRecord
    from .v_card_summary import VCardSummary
    from .value_templates import ValueTemplates
    from .vendor_check_number import VendorCheckNumber
    from .vendor_data import VendorData
    from .vendor_data_response import VendorDataResponse
    from .vendor_data_response_payment_method import VendorDataResponsePaymentMethod
    from .vendor_ein import VendorEin
    from .vendor_name_1 import VendorName1
    from .vendor_name_2 import VendorName2
    from .vendor_number import VendorNumber
    from .vendor_out_data import VendorOutData
    from .vendor_payment_method import VendorPaymentMethod
    from .vendor_payment_method_string import VendorPaymentMethodString
    from .vendor_phone import VendorPhone
    from .vendor_query_record import VendorQueryRecord
    from .vendor_response_billing_data import VendorResponseBillingData
    from .vendor_response_stored_method import VendorResponseStoredMethod
    from .vendor_response_summary import VendorResponseSummary
    from .vendor_summary import VendorSummary
    from .vendorid import Vendorid
    from .vendorstatus import Vendorstatus
    from .visible import Visible
    from .wallet_cascade import WalletCascade
    from .wallet_is_enabled import WalletIsEnabled
    from .website import Website
    from .whencharged import Whencharged
    from .whendelivered import Whendelivered
    from .whenprovided import Whenprovided
    from .whenrefunded import Whenrefunded
    from .zip import Zip
_dynamic_imports: typing.Dict[str, str] = {
    "ASection": ".a_section",
    "AcceptOauth": ".accept_oauth",
    "AcceptRegister": ".accept_register",
    "AccountNumber": ".account_number",
    "Accountexp": ".accountexp",
    "Accountid": ".accountid",
    "AccountingField": ".accounting_field",
    "Accounttype": ".accounttype",
    "Accountzip": ".accountzip",
    "Ach": ".ach",
    "AchAbsorbSection": ".ach_absorb_section",
    "AchAcceptanceElement": ".ach_acceptance_element",
    "AchFeeSection": ".ach_fee_section",
    "AchHolder": ".ach_holder",
    "AchHolderType": ".ach_holder_type",
    "AchLinkTypes": ".ach_link_types",
    "AchPassThroughSection": ".ach_pass_through_section",
    "AchPaymentMethod": ".ach_payment_method",
    "AchSecCode": ".ach_sec_code",
    "AchSection": ".ach_section",
    "AchService": ".ach_service",
    "AchSetup": ".ach_setup",
    "AchTypes": ".ach_types",
    "AchTypesPass": ".ach_types_pass",
    "AchTypesTiers": ".ach_types_tiers",
    "AchValidation": ".ach_validation",
    "Achaccount": ".achaccount",
    "Achaccounttype": ".achaccounttype",
    "Achrouting": ".achrouting",
    "AddPaymentMethodDomainApiResponse": ".add_payment_method_domain_api_response",
    "AdditionalData": ".additional_data",
    "AdditionalDataMap": ".additional_data_map",
    "AdditionalDataString": ".additional_data_string",
    "AddressAddtlNullable": ".address_addtl_nullable",
    "AddressNullable": ".address_nullable",
    "AmountElement": ".amount_element",
    "Annualrevenue": ".annualrevenue",
    "AppId": ".app_id",
    "ApplePayData": ".apple_pay_data",
    "ApplePayId": ".apple_pay_id",
    "ApplePayMetadata": ".apple_pay_metadata",
    "ApplePayOrganizationUpdateData": ".apple_pay_organization_update_data",
    "ApplePayPaypointRegistrationData": ".apple_pay_paypoint_registration_data",
    "ApplePayStatusData": ".apple_pay_status_data",
    "ApplePayType": ".apple_pay_type",
    "AppleWalletData": ".apple_wallet_data",
    "ApplicationData": ".application_data",
    "ApplicationDataManaged": ".application_data_managed",
    "ApplicationDataManagedContactsItem": ".application_data_managed_contacts_item",
    "ApplicationDataManagedOwnershipItem": ".application_data_managed_ownership_item",
    "ApplicationDataOdp": ".application_data_odp",
    "ApplicationDataOdpContactsItem": ".application_data_odp_contacts_item",
    "ApplicationDataOdpOwnershipItem": ".application_data_odp_ownership_item",
    "ApplicationDataPayIn": ".application_data_pay_in",
    "ApplicationDataPayInBankData": ".application_data_pay_in_bank_data",
    "ApplicationDataPayInContactsItem": ".application_data_pay_in_contacts_item",
    "ApplicationDataPayInOwnershipItem": ".application_data_pay_in_ownership_item",
    "ApplicationDataPayInServices": ".application_data_pay_in_services",
    "ApplicationDataPayInServicesAch": ".application_data_pay_in_services_ach",
    "ApplicationDataPayInServicesCard": ".application_data_pay_in_services_card",
    "ApplicationDetailsRecord": ".application_details_record",
    "ApplicationDetailsRecordMessagesItem": ".application_details_record_messages_item",
    "ApplicationQueryRecord": ".application_query_record",
    "AssociatedVendor": ".associated_vendor",
    "Attachments": ".attachments",
    "AttestationDate": ".attestation_date",
    "Authcode": ".authcode",
    "AutoElement": ".auto_element",
    "Avgmonthly": ".avgmonthly",
    "Avgticketamt": ".avgticketamt",
    "Avsresponsetext": ".avsresponsetext",
    "BAddress": ".b_address",
    "BDetails": ".b_details",
    "BSection": ".b_section",
    "Baddress1": ".baddress_1",
    "Baddress2": ".baddress_2",
    "Bank": ".bank",
    "BankAccountFunction": ".bank_account_function",
    "BankAccountHolderName": ".bank_account_holder_name",
    "BankAccountHolderType": ".bank_account_holder_type",
    "BankData": ".bank_data",
    "BankName": ".bank_name",
    "BankNickname": ".bank_nickname",
    "BankSection": ".bank_section",
    "BasicTable": ".basic_table",
    "BasicTemplateElement": ".basic_template_element",
    "BatchNumber": ".batch_number",
    "BatchSummary": ".batch_summary",
    "Bcity": ".bcity",
    "Bcountry": ".bcountry",
    "BillApprovals": ".bill_approvals",
    "BillData": ".bill_data",
    "BillDataPaymentTerms": ".bill_data_payment_terms",
    "BillDetailResponse": ".bill_detail_response",
    "BillDetailsResponse": ".bill_details_response",
    "BillEvents": ".bill_events",
    "BillId": ".bill_id",
    "BillItem": ".bill_item",
    "BillOptions": ".bill_options",
    "BillPayOutData": ".bill_pay_out_data",
    "BillPayOutDataRequest": ".bill_pay_out_data_request",
    "BillQueryRecord2": ".bill_query_record_2",
    "BillQueryRecord2BillApprovalsItem": ".bill_query_record_2_bill_approvals_item",
    "BillQueryRecord2PaymentMethod": ".bill_query_record_2_payment_method",
    "BillQueryResponse": ".bill_query_response",
    "BillQueryResponseSummary": ".bill_query_response_summary",
    "BillingAddressAddtlNullable": ".billing_address_addtl_nullable",
    "BillingAddressNullable": ".billing_address_nullable",
    "BillingCityNullable": ".billing_city_nullable",
    "BillingCountryNullable": ".billing_country_nullable",
    "BillingData": ".billing_data",
    "BillingDataResponse": ".billing_data_response",
    "BillingFeeDetail": ".billing_fee_detail",
    "BillingStateNullable": ".billing_state_nullable",
    "BillingZip": ".billing_zip",
    "Billitems": ".billitems",
    "Billstatus": ".billstatus",
    "BinData": ".bin_data",
    "Binperson": ".binperson",
    "Binphone": ".binphone",
    "Binweb": ".binweb",
    "Bnk": ".bnk",
    "BoardingApplicationAttachments": ".boarding_application_attachments",
    "BoardingAverageBillSize": ".boarding_average_bill_size",
    "BoardingAvgMonthlyBill": ".boarding_avg_monthly_bill",
    "BoardingBusinessFax": ".boarding_business_fax",
    "BoardingBusinessPhone": ".boarding_business_phone",
    "BoardingId": ".boarding_id",
    "BoardingLinkApiResponse": ".boarding_link_api_response",
    "BoardingLinkId": ".boarding_link_id",
    "BoardingLinkQueryRecord": ".boarding_link_query_record",
    "BoardingQueryLinks": ".boarding_query_links",
    "BoardingStatus": ".boarding_status",
    "Bphone": ".bphone",
    "Bstate": ".bstate",
    "Bsummary": ".bsummary",
    "BuilderData": ".builder_data",
    "BusinessSection": ".business_section",
    "Busstartdate": ".busstartdate",
    "ButtonElement": ".button_element",
    "ButtonElementSize": ".button_element_size",
    "Bzip": ".bzip",
    "CList": ".c_list",
    "CardAcceptanceElement": ".card_acceptance_element",
    "CardFeeSection": ".card_fee_section",
    "CardFlatSection": ".card_flat_section",
    "CardIcpSection": ".card_icp_section",
    "CardLinkTypes": ".card_link_types",
    "CardPassThroughSection": ".card_pass_through_section",
    "CardSection": ".card_section",
    "CardService": ".card_service",
    "CardSetup": ".card_setup",
    "CardType": ".card_type",
    "CardTypePass": ".card_type_pass",
    "CardTypes": ".card_types",
    "Cardcvv": ".cardcvv",
    "Cardexp": ".cardexp",
    "Cardholder": ".cardholder",
    "Cardnumber": ".cardnumber",
    "Cardzip": ".cardzip",
    "Cascade": ".cascade",
    "CascadeJobDetails": ".cascade_job_details",
    "Cash": ".cash",
    "Category": ".category",
    "ChargebackId": ".chargeback_id",
    "Check": ".check",
    "CityNullable": ".city_nullable",
    "CloudQueryApiResponse": ".cloud_query_api_response",
    "Comments": ".comments",
    "ConfigureApplePayOrganizationApiResponse": ".configure_apple_pay_organization_api_response",
    "ConfigureApplePaypointApiResponse": ".configure_apple_paypoint_api_response",
    "ConfigureGooglePaypointApiResponse": ".configure_google_paypoint_api_response",
    "ContactElement": ".contact_element",
    "Contacts": ".contacts",
    "ContactsField": ".contacts_field",
    "ContactsResponse": ".contacts_response",
    "CountryNullable": ".country_nullable",
    "CreatedAt": ".created_at",
    "CustomerData": ".customer_data",
    "CustomerId": ".customer_id",
    "CustomerNumberNullable": ".customer_number_nullable",
    "CustomerQueryRecords": ".customer_query_records",
    "CustomerQueryRecordsCustomerConsent": ".customer_query_records_customer_consent",
    "CustomerQueryRecordsCustomerConsentECommunication": ".customer_query_records_customer_consent_e_communication",
    "CustomerQueryRecordsCustomerConsentSms": ".customer_query_records_customer_consent_sms",
    "CustomerStatus": ".customer_status",
    "CustomerSummaryRecord": ".customer_summary_record",
    "Customeridtrans": ".customeridtrans",
    "Cvvresponsetext": ".cvvresponsetext",
    "DSection": ".d_section",
    "Datenullable": ".datenullable",
    "DatetimeNullable": ".datetime_nullable",
    "Dbaname": ".dbaname",
    "DepositDate": ".deposit_date",
    "Descriptor": ".descriptor",
    "Device": ".device",
    "DeviceId": ".device_id",
    "Discount": ".discount",
    "DisplayProperty": ".display_property",
    "DocumentSection": ".document_section",
    "DocumentSectionTermsAndConditions": ".document_section_terms_and_conditions",
    "DocumentSectionTermsAndConditionsTcLinksItem": ".document_section_terms_and_conditions_tc_links_item",
    "DocumentsRef": ".documents_ref",
    "DomainName": ".domain_name",
    "DutyAmount": ".duty_amount",
    "Ein": ".ein",
    "Element": ".element",
    "Email": ".email",
    "Enabled": ".enabled",
    "EnrollmentStatus": ".enrollment_status",
    "EntityId": ".entity_id",
    "EntityType": ".entity_type",
    "Entry": ".entry",
    "EntryAttributes": ".entry_attributes",
    "EntrypageId": ".entrypage_id",
    "Entrypointfield": ".entrypointfield",
    "ExpectedDepositDate": ".expected_deposit_date",
    "ExpectedProcessingDateTime": ".expected_processing_date_time",
    "ExportFormat": ".export_format",
    "ExternalPaypointId": ".external_paypoint_id",
    "ExternalProcessorInformation": ".external_processor_information",
    "FaxNumber": ".fax_number",
    "FeeAmount": ".fee_amount",
    "File": ".file",
    "FileContent": ".file_content",
    "FileContentFtype": ".file_content_ftype",
    "Finishtype": ".finishtype",
    "ForceCustomerCreation": ".force_customer_creation",
    "FreightAmount": ".freight_amount",
    "Frequency": ".frequency",
    "FrequencyList": ".frequency_list",
    "Frequencynotification": ".frequencynotification",
    "Gatewayfield": ".gatewayfield",
    "GeneralEvents": ".general_events",
    "GooglePayData": ".google_pay_data",
    "GooglePayMetadata": ".google_pay_metadata",
    "GooglePayPaypointRegistrationData": ".google_pay_paypoint_registration_data",
    "GooglePayStatusData": ".google_pay_status_data",
    "GoogleWalletData": ".google_wallet_data",
    "HasVcardTransactions": ".has_vcard_transactions",
    "HeaderElement": ".header_element",
    "Highticketamt": ".highticketamt",
    "Holdername": ".holdername",
    "IdempotencyKey": ".idempotency_key",
    "Identifierfields": ".identifierfields",
    "Idpaypoint": ".idpaypoint",
    "Initiator": ".initiator",
    "Instrument": ".instrument",
    "InternalReferenceId": ".internal_reference_id",
    "InvoiceAmount": ".invoice_amount",
    "InvoiceElement": ".invoice_element",
    "InvoiceNumber": ".invoice_number",
    "InvoiceType": ".invoice_type",
    "Invoicestatus": ".invoicestatus",
    "IpAddress": ".ip_address",
    "IsEnabled": ".is_enabled",
    "IsRoot": ".is_root",
    "IsSameDayAch": ".is_same_day_ach",
    "IsSuccess": ".is_success",
    "ItemCommodityCode": ".item_commodity_code",
    "ItemDescription": ".item_description",
    "ItemProductCode": ".item_product_code",
    "ItemProductName": ".item_product_name",
    "ItemUnitofMeasure": ".item_unitof_measure",
    "JobId": ".job_id",
    "JobStatus": ".job_status",
    "KeyValue": ".key_value",
    "KeyValueDuo": ".key_value_duo",
    "LabelElement": ".label_element",
    "Language": ".language",
    "LastModified": ".last_modified",
    "Legalname": ".legalname",
    "License": ".license",
    "Licensestate": ".licensestate",
    "LineItem": ".line_item",
    "LineItemQueryRecord": ".line_item_query_record",
    "LinkData": ".link_data",
    "LinkRow": ".link_row",
    "LocationCode": ".location_code",
    "Maddress": ".maddress",
    "Maddress1": ".maddress_1",
    "Maskedaccount": ".maskedaccount",
    "Mcc": ".mcc",
    "Mcity": ".mcity",
    "Mcountry": ".mcountry",
    "MethodElement": ".method_element",
    "MethodElementSettings": ".method_element_settings",
    "MethodElementSettingsApplePay": ".method_element_settings_apple_pay",
    "MethodElementSettingsApplePayButtonStyle": ".method_element_settings_apple_pay_button_style",
    "MethodElementSettingsApplePayButtonType": ".method_element_settings_apple_pay_button_type",
    "MethodElementSettingsApplePayLanguage": ".method_element_settings_apple_pay_language",
    "MethodQueryRecords": ".method_query_records",
    "MethodReferenceId": ".method_reference_id",
    "Methodall": ".methodall",
    "Methodnotification": ".methodnotification",
    "MethodsList": ".methods_list",
    "Mfa": ".mfa",
    "MfaData": ".mfa_data",
    "MfaMode": ".mfa_mode",
    "MfaValidationCode": ".mfa_validation_code",
    "Mstate": ".mstate",
    "Mzip": ".mzip",
    "NameUser": ".name_user",
    "NetAmountstring": ".net_amountstring",
    "Netamountnullable": ".netamountnullable",
    "NoteElement": ".note_element",
    "NotificationContent": ".notification_content",
    "NotificationContentEventType": ".notification_content_event_type",
    "NotificationContentFileFormat": ".notification_content_file_format",
    "NotificationContentReportName": ".notification_content_report_name",
    "NotificationId": ".notification_id",
    "NotificationQueryRecord": ".notification_query_record",
    "NotificationReportRequest": ".notification_report_request",
    "NotificationReportRequestContent": ".notification_report_request_content",
    "NotificationReportRequestContentFileFormat": ".notification_report_request_content_file_format",
    "NotificationReportRequestContentReportName": ".notification_report_request_content_report_name",
    "NotificationReportRequestFrequency": ".notification_report_request_frequency",
    "NotificationReportRequestMethod": ".notification_report_request_method",
    "NotificationStandardRequest": ".notification_standard_request",
    "NotificationStandardRequestContent": ".notification_standard_request_content",
    "NotificationStandardRequestContentEventType": ".notification_standard_request_content_event_type",
    "NotificationStandardRequestFrequency": ".notification_standard_request_frequency",
    "NotificationStandardRequestMethod": ".notification_standard_request_method",
    "OList": ".o_list",
    "OSection": ".o_section",
    "OdpSetup": ".odp_setup",
    "OdpSetupProcessingRegion": ".odp_setup_processing_region",
    "Operation": ".operation",
    "OptinStatus": ".optin_status",
    "Order": ".order",
    "OrderId": ".order_id",
    "Orderdescription": ".orderdescription",
    "OrgData": ".org_data",
    "OrgParentId": ".org_parent_id",
    "OrgParentName": ".org_parent_name",
    "OrgScope": ".org_scope",
    "OrgXScope": ".org_x_scope",
    "Orgaddress": ".orgaddress",
    "OrganizationId": ".organization_id",
    "OrganizationQueryRecord": ".organization_query_record",
    "OrganizationQueryRecordServicesItem": ".organization_query_record_services_item",
    "OrganizationUpdates": ".organization_updates",
    "Orgcity": ".orgcity",
    "Orgcountry": ".orgcountry",
    "Orgentryname": ".orgentryname",
    "Orgid": ".orgid",
    "Orgidstring": ".orgidstring",
    "Orgname": ".orgname",
    "Orgstate": ".orgstate",
    "Orgtimezone": ".orgtimezone",
    "Orgtype": ".orgtype",
    "Orgwebsite": ".orgwebsite",
    "Orgzip": ".orgzip",
    "OwnType": ".own_type",
    "OwnerEntityId": ".owner_entity_id",
    "OwnerEntityType": ".owner_entity_type",
    "Ownerid": ".ownerid",
    "Owners": ".owners",
    "OwnersSection": ".owners_section",
    "Ownership": ".ownership",
    "Ownertype": ".ownertype",
    "PSection": ".p_section",
    "PageContent": ".page_content",
    "PageElement": ".page_element",
    "PageIdentifier": ".page_identifier",
    "PageSetting": ".page_setting",
    "PagelinkSetting": ".pagelink_setting",
    "Pagesize": ".pagesize",
    "PairFiles": ".pair_files",
    "PayCategory": ".pay_category",
    "PayMethodAch": ".pay_method_ach",
    "PayMethodBodyAllFields": ".pay_method_body_all_fields",
    "PayMethodCloud": ".pay_method_cloud",
    "PayMethodCredit": ".pay_method_credit",
    "PayMethodStoredMethod": ".pay_method_stored_method",
    "PayMethodStoredMethodMethod": ".pay_method_stored_method_method",
    "PayabliApiResponse": ".payabli_api_response",
    "PayabliApiResponse0": ".payabli_api_response_0",
    "PayabliApiResponse00": ".payabli_api_response_00",
    "PayabliApiResponse0000": ".payabli_api_response_0000",
    "PayabliApiResponse00Responsedatanonobject": ".payabli_api_response_00_responsedatanonobject",
    "PayabliApiResponse0ResponseData": ".payabli_api_response_0_response_data",
    "PayabliApiResponse6": ".payabli_api_response_6",
    "PayabliApiResponseCustomerQuery": ".payabli_api_response_customer_query",
    "PayabliApiResponseError400": ".payabli_api_response_error_400",
    "PayabliApiResponseError400ResponseData": ".payabli_api_response_error_400_response_data",
    "PayabliApiResponseGeneric2Part": ".payabli_api_response_generic_2_part",
    "PayabliApiResponseImport": ".payabli_api_response_import",
    "PayabliApiResponseImportResponseData": ".payabli_api_response_import_response_data",
    "PayabliApiResponseMfaBasic": ".payabli_api_response_mfa_basic",
    "PayabliApiResponseNotifications": ".payabli_api_response_notifications",
    "PayabliApiResponseNotificationsResponseData": ".payabli_api_response_notifications_response_data",
    "PayabliApiResponsePaylinks": ".payabli_api_response_paylinks",
    "PayabliApiResponsePaymethodDelete": ".payabli_api_response_paymethod_delete",
    "PayabliApiResponsePaymethodDeleteResponseData": ".payabli_api_response_paymethod_delete_response_data",
    "PayabliApiResponseTemplateId": ".payabli_api_response_template_id",
    "PayabliApiResponseUserMfa": ".payabli_api_response_user_mfa",
    "PayabliApiResponseVendors": ".payabli_api_response_vendors",
    "PayabliCredentials": ".payabli_credentials",
    "PayabliCredentialsPascal": ".payabli_credentials_pascal",
    "PayabliPages": ".payabli_pages",
    "PayeeName": ".payee_name",
    "PaylinkId": ".paylink_id",
    "PaymentCategories": ".payment_categories",
    "PaymentDetail": ".payment_detail",
    "PaymentDetailCredit": ".payment_detail_credit",
    "PaymentIdString": ".payment_id_string",
    "PaymentMethod": ".payment_method",
    "PaymentMethodDomainApiResponse": ".payment_method_domain_api_response",
    "PaymentMethodDomainGeneralResponse": ".payment_method_domain_general_response",
    "PaymentMethodDomainId": ".payment_method_domain_id",
    "PaymentTransStatusDescription": ".payment_trans_status_description",
    "Paymentid": ".paymentid",
    "PayorDataRequest": ".payor_data_request",
    "PayorDataResponse": ".payor_data_response",
    "PayorElement": ".payor_element",
    "PayorFields": ".payor_fields",
    "PayorId": ".payor_id",
    "PayoutAverageMonthlyVolume": ".payout_average_monthly_volume",
    "PayoutAverageTicketLimit": ".payout_average_ticket_limit",
    "PayoutCreditLimit": ".payout_credit_limit",
    "PayoutGatewayConnector": ".payout_gateway_connector",
    "PayoutHighTicketAmount": ".payout_high_ticket_amount",
    "PayoutProgram": ".payout_program",
    "PaypointData": ".paypoint_data",
    "PaypointEntryConfig": ".paypoint_entry_config",
    "PaypointId": ".paypoint_id",
    "PaypointName": ".paypoint_name",
    "PaypointSummary": ".paypoint_summary",
    "Paypointstatus": ".paypointstatus",
    "PciAttestation": ".pci_attestation",
    "PendingFeeAmount": ".pending_fee_amount",
    "PhoneNumber": ".phone_number",
    "PoiDevice": ".poi_device",
    "PolicyId": ".policy_id",
    "PosCol": ".pos_col",
    "PosRow": ".pos_row",
    "ProcessingSection": ".processing_section",
    "PurchaseOrder": ".purchase_order",
    "PushPayLinkRequest": ".push_pay_link_request",
    "PushPayLinkRequestEmail": ".push_pay_link_request_email",
    "PushPayLinkRequestSms": ".push_pay_link_request_sms",
    "PushPayLinkRequest_Email": ".push_pay_link_request",
    "PushPayLinkRequest_Sms": ".push_pay_link_request",
    "QueryBatchesOutResponse": ".query_batches_out_response",
    "QueryBatchesOutResponseRecordsItem": ".query_batches_out_response_records_item",
    "QueryBoardingAppsListResponse": ".query_boarding_apps_list_response",
    "QueryBoardingLinksResponse": ".query_boarding_links_response",
    "QueryBoardingLinksResponseRecordsItem": ".query_boarding_links_response_records_item",
    "QueryCFeeTransaction": ".query_c_fee_transaction",
    "QueryChargebacksResponse": ".query_chargebacks_response",
    "QueryChargebacksResponseRecordsItem": ".query_chargebacks_response_records_item",
    "QueryCustomerResponse": ".query_customer_response",
    "QueryEntrypointResponse": ".query_entrypoint_response",
    "QueryEntrypointResponseRecordsItem": ".query_entrypoint_response_records_item",
    "QueryPaymentData": ".query_payment_data",
    "QueryPayoutTransaction": ".query_payout_transaction",
    "QueryPayoutTransactionRecordsItem": ".query_payout_transaction_records_item",
    "QueryPayoutTransactionRecordsItemPaymentData": ".query_payout_transaction_records_item_payment_data",
    "QueryPayoutTransactionSummary": ".query_payout_transaction_summary",
    "QueryResponse": ".query_response",
    "QueryResponseData": ".query_response_data",
    "QueryResponseItems": ".query_response_items",
    "QueryResponseItemsRecordsItem": ".query_response_items_records_item",
    "QueryResponseNotificationReports": ".query_response_notification_reports",
    "QueryResponseNotificationReportsRecordsItem": ".query_response_notification_reports_records_item",
    "QueryResponseNotifications": ".query_response_notifications",
    "QueryResponseNotificationsRecordsItem": ".query_response_notifications_records_item",
    "QueryResponseSettlements": ".query_response_settlements",
    "QueryResponseSettlementsRecordsItem": ".query_response_settlements_records_item",
    "QueryResponseSettlementsSummary": ".query_response_settlements_summary",
    "QueryResponseTransactions": ".query_response_transactions",
    "QueryResponseVendors": ".query_response_vendors",
    "QuerySubscriptionResponse": ".query_subscription_response",
    "QuerySummary": ".query_summary",
    "QuerySummaryNoAmt": ".query_summary_no_amt",
    "QueryTransactionEvents": ".query_transaction_events",
    "QueryTransactionEventsEventData": ".query_transaction_events_event_data",
    "QueryTransactionPayorData": ".query_transaction_payor_data",
    "QueryUserResponse": ".query_user_response",
    "ReadOnly": ".read_only",
    "ReceiptContent": ".receipt_content",
    "RecipientEmailNotification": ".recipient_email_notification",
    "ReferenceName": ".reference_name",
    "ReferenceTemplateId": ".reference_template_id",
    "Referenceidtrans": ".referenceidtrans",
    "RefundDetail": ".refund_detail",
    "RefundId": ".refund_id",
    "RemitEmail": ".remit_email",
    "Remitaddress1": ".remitaddress_1",
    "Remitaddress2": ".remitaddress_2",
    "Remitcity": ".remitcity",
    "Remitcountry": ".remitcountry",
    "Remitstate": ".remitstate",
    "Remitzip": ".remitzip",
    "RepCode": ".rep_code",
    "RepName": ".rep_name",
    "RepOffice": ".rep_office",
    "ReplyToEmail": ".reply_to_email",
    "Replyby": ".replyby",
    "RequiredElement": ".required_element",
    "ResponseText": ".response_text",
    "Responsecode": ".responsecode",
    "Responsedata": ".responsedata",
    "Responsedatanonobject": ".responsedatanonobject",
    "ResultCode": ".result_code",
    "Resulttext": ".resulttext",
    "Resumable": ".resumable",
    "RetrievalId": ".retrieval_id",
    "ReturnedId": ".returned_id",
    "RiskAction": ".risk_action",
    "RiskActionCode": ".risk_action_code",
    "RiskFlagged": ".risk_flagged",
    "RiskFlaggedOn": ".risk_flagged_on",
    "RiskReason": ".risk_reason",
    "RiskStatus": ".risk_status",
    "RoomIdNotInUse": ".room_id_not_in_use",
    "RoutingAccount": ".routing_account",
    "SSection": ".s_section",
    "SalesCode": ".sales_code",
    "SalesSection": ".sales_section",
    "SaveIfSuccess": ".save_if_success",
    "ScheduleDetail": ".schedule_detail",
    "ScheduleId": ".schedule_id",
    "Sequence": ".sequence",
    "ServiceCost": ".service_cost",
    "Services": ".services",
    "ServicesSection": ".services_section",
    "SettingElement": ".setting_element",
    "SettingsQueryRecord": ".settings_query_record",
    "SettlementStatus": ".settlement_status",
    "SettlementStatusPayout": ".settlement_status_payout",
    "ShippingFromZip": ".shipping_from_zip",
    "Shippingaddress": ".shippingaddress",
    "Shippingaddressadditional": ".shippingaddressadditional",
    "Shippingcity": ".shippingcity",
    "Shippingcountry": ".shippingcountry",
    "Shippingstate": ".shippingstate",
    "Shippingzip": ".shippingzip",
    "SignDate": ".sign_date",
    "Signaturedata": ".signaturedata",
    "SignedDocumentReference": ".signed_document_reference",
    "SignerAcceptance": ".signer_acceptance",
    "SignerAddress1": ".signer_address_1",
    "SignerCity": ".signer_city",
    "SignerCountry": ".signer_country",
    "SignerData": ".signer_data",
    "SignerDataRequest": ".signer_data_request",
    "SignerDob": ".signer_dob",
    "SignerName": ".signer_name",
    "SignerPhone": ".signer_phone",
    "SignerSection": ".signer_section",
    "SignerSsn": ".signer_ssn",
    "SignerState": ".signer_state",
    "SignerZip": ".signer_zip",
    "Signeraddress": ".signeraddress",
    "Source": ".source",
    "SplitFunding": ".split_funding",
    "SplitFundingContent": ".split_funding_content",
    "SplitFundingRefundContent": ".split_funding_refund_content",
    "StateNullable": ".state_nullable",
    "Statusnotification": ".statusnotification",
    "StoredMethodUsageType": ".stored_method_usage_type",
    "Storedmethodid": ".storedmethodid",
    "SubFooter": ".sub_footer",
    "SubHeader": ".sub_header",
    "Subdomain": ".subdomain",
    "SubscriptionQueryRecords": ".subscription_query_records",
    "Subscriptionid": ".subscriptionid",
    "SummaryCommodityCode": ".summary_commodity_code",
    "SummaryOrg": ".summary_org",
    "Target": ".target",
    "Tax": ".tax",
    "Taxfillname": ".taxfillname",
    "TemplateAdditionalDataField": ".template_additional_data_field",
    "TemplateAdditionalDataSection": ".template_additional_data_section",
    "TemplateCode": ".template_code",
    "TemplateContent": ".template_content",
    "TemplateContentResponse": ".template_content_response",
    "TemplateData": ".template_data",
    "TemplateElement": ".template_element",
    "TemplateId": ".template_id",
    "TemplateName": ".template_name",
    "TemplateQueryRecord": ".template_query_record",
    "TemplateQueryResponse": ".template_query_response",
    "Terms": ".terms",
    "TermsConditions": ".terms_conditions",
    "Ticketamt": ".ticketamt",
    "TierItem": ".tier_item",
    "TierItemPass": ".tier_item_pass",
    "Timezone": ".timezone",
    "Totalpages": ".totalpages",
    "Totalrecords": ".totalrecords",
    "TransStatus": ".trans_status",
    "TransactionOutQueryRecord": ".transaction_out_query_record",
    "TransactionQueryRecords": ".transaction_query_records",
    "TransactionTime": ".transaction_time",
    "Transfer": ".transfer",
    "TransferBankAccount": ".transfer_bank_account",
    "TransferIdentifier": ".transfer_identifier",
    "TransferMessage": ".transfer_message",
    "TransferMessageProperties": ".transfer_message_properties",
    "TransferQueryResponse": ".transfer_query_response",
    "TransferSummary": ".transfer_summary",
    "TypeAccount": ".type_account",
    "UnderWritingMethod": ".under_writing_method",
    "UnderwritingData": ".underwriting_data",
    "UnderwritingDataResponse": ".underwriting_data_response",
    "UserData": ".user_data",
    "UserQueryRecord": ".user_query_record",
    "UsrAccess": ".usr_access",
    "UsrStatus": ".usr_status",
    "VCardQueryResponse": ".v_card_query_response",
    "VCardRecord": ".v_card_record",
    "VCardSummary": ".v_card_summary",
    "ValueTemplates": ".value_templates",
    "VendorCheckNumber": ".vendor_check_number",
    "VendorData": ".vendor_data",
    "VendorDataResponse": ".vendor_data_response",
    "VendorDataResponsePaymentMethod": ".vendor_data_response_payment_method",
    "VendorEin": ".vendor_ein",
    "VendorName1": ".vendor_name_1",
    "VendorName2": ".vendor_name_2",
    "VendorNumber": ".vendor_number",
    "VendorOutData": ".vendor_out_data",
    "VendorPaymentMethod": ".vendor_payment_method",
    "VendorPaymentMethodString": ".vendor_payment_method_string",
    "VendorPhone": ".vendor_phone",
    "VendorQueryRecord": ".vendor_query_record",
    "VendorResponseBillingData": ".vendor_response_billing_data",
    "VendorResponseStoredMethod": ".vendor_response_stored_method",
    "VendorResponseSummary": ".vendor_response_summary",
    "VendorSummary": ".vendor_summary",
    "Vendorid": ".vendorid",
    "Vendorstatus": ".vendorstatus",
    "Visible": ".visible",
    "WalletCascade": ".wallet_cascade",
    "WalletIsEnabled": ".wallet_is_enabled",
    "Website": ".website",
    "Whencharged": ".whencharged",
    "Whendelivered": ".whendelivered",
    "Whenprovided": ".whenprovided",
    "Whenrefunded": ".whenrefunded",
    "Zip": ".zip",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ASection",
    "AcceptOauth",
    "AcceptRegister",
    "AccountNumber",
    "Accountexp",
    "Accountid",
    "AccountingField",
    "Accounttype",
    "Accountzip",
    "Ach",
    "AchAbsorbSection",
    "AchAcceptanceElement",
    "AchFeeSection",
    "AchHolder",
    "AchHolderType",
    "AchLinkTypes",
    "AchPassThroughSection",
    "AchPaymentMethod",
    "AchSecCode",
    "AchSection",
    "AchService",
    "AchSetup",
    "AchTypes",
    "AchTypesPass",
    "AchTypesTiers",
    "AchValidation",
    "Achaccount",
    "Achaccounttype",
    "Achrouting",
    "AddPaymentMethodDomainApiResponse",
    "AdditionalData",
    "AdditionalDataMap",
    "AdditionalDataString",
    "AddressAddtlNullable",
    "AddressNullable",
    "AmountElement",
    "Annualrevenue",
    "AppId",
    "ApplePayData",
    "ApplePayId",
    "ApplePayMetadata",
    "ApplePayOrganizationUpdateData",
    "ApplePayPaypointRegistrationData",
    "ApplePayStatusData",
    "ApplePayType",
    "AppleWalletData",
    "ApplicationData",
    "ApplicationDataManaged",
    "ApplicationDataManagedContactsItem",
    "ApplicationDataManagedOwnershipItem",
    "ApplicationDataOdp",
    "ApplicationDataOdpContactsItem",
    "ApplicationDataOdpOwnershipItem",
    "ApplicationDataPayIn",
    "ApplicationDataPayInBankData",
    "ApplicationDataPayInContactsItem",
    "ApplicationDataPayInOwnershipItem",
    "ApplicationDataPayInServices",
    "ApplicationDataPayInServicesAch",
    "ApplicationDataPayInServicesCard",
    "ApplicationDetailsRecord",
    "ApplicationDetailsRecordMessagesItem",
    "ApplicationQueryRecord",
    "AssociatedVendor",
    "Attachments",
    "AttestationDate",
    "Authcode",
    "AutoElement",
    "Avgmonthly",
    "Avgticketamt",
    "Avsresponsetext",
    "BAddress",
    "BDetails",
    "BSection",
    "Baddress1",
    "Baddress2",
    "Bank",
    "BankAccountFunction",
    "BankAccountHolderName",
    "BankAccountHolderType",
    "BankData",
    "BankName",
    "BankNickname",
    "BankSection",
    "BasicTable",
    "BasicTemplateElement",
    "BatchNumber",
    "BatchSummary",
    "Bcity",
    "Bcountry",
    "BillApprovals",
    "BillData",
    "BillDataPaymentTerms",
    "BillDetailResponse",
    "BillDetailsResponse",
    "BillEvents",
    "BillId",
    "BillItem",
    "BillOptions",
    "BillPayOutData",
    "BillPayOutDataRequest",
    "BillQueryRecord2",
    "BillQueryRecord2BillApprovalsItem",
    "BillQueryRecord2PaymentMethod",
    "BillQueryResponse",
    "BillQueryResponseSummary",
    "BillingAddressAddtlNullable",
    "BillingAddressNullable",
    "BillingCityNullable",
    "BillingCountryNullable",
    "BillingData",
    "BillingDataResponse",
    "BillingFeeDetail",
    "BillingStateNullable",
    "BillingZip",
    "Billitems",
    "Billstatus",
    "BinData",
    "Binperson",
    "Binphone",
    "Binweb",
    "Bnk",
    "BoardingApplicationAttachments",
    "BoardingAverageBillSize",
    "BoardingAvgMonthlyBill",
    "BoardingBusinessFax",
    "BoardingBusinessPhone",
    "BoardingId",
    "BoardingLinkApiResponse",
    "BoardingLinkId",
    "BoardingLinkQueryRecord",
    "BoardingQueryLinks",
    "BoardingStatus",
    "Bphone",
    "Bstate",
    "Bsummary",
    "BuilderData",
    "BusinessSection",
    "Busstartdate",
    "ButtonElement",
    "ButtonElementSize",
    "Bzip",
    "CList",
    "CardAcceptanceElement",
    "CardFeeSection",
    "CardFlatSection",
    "CardIcpSection",
    "CardLinkTypes",
    "CardPassThroughSection",
    "CardSection",
    "CardService",
    "CardSetup",
    "CardType",
    "CardTypePass",
    "CardTypes",
    "Cardcvv",
    "Cardexp",
    "Cardholder",
    "Cardnumber",
    "Cardzip",
    "Cascade",
    "CascadeJobDetails",
    "Cash",
    "Category",
    "ChargebackId",
    "Check",
    "CityNullable",
    "CloudQueryApiResponse",
    "Comments",
    "ConfigureApplePayOrganizationApiResponse",
    "ConfigureApplePaypointApiResponse",
    "ConfigureGooglePaypointApiResponse",
    "ContactElement",
    "Contacts",
    "ContactsField",
    "ContactsResponse",
    "CountryNullable",
    "CreatedAt",
    "CustomerData",
    "CustomerId",
    "CustomerNumberNullable",
    "CustomerQueryRecords",
    "CustomerQueryRecordsCustomerConsent",
    "CustomerQueryRecordsCustomerConsentECommunication",
    "CustomerQueryRecordsCustomerConsentSms",
    "CustomerStatus",
    "CustomerSummaryRecord",
    "Customeridtrans",
    "Cvvresponsetext",
    "DSection",
    "Datenullable",
    "DatetimeNullable",
    "Dbaname",
    "DepositDate",
    "Descriptor",
    "Device",
    "DeviceId",
    "Discount",
    "DisplayProperty",
    "DocumentSection",
    "DocumentSectionTermsAndConditions",
    "DocumentSectionTermsAndConditionsTcLinksItem",
    "DocumentsRef",
    "DomainName",
    "DutyAmount",
    "Ein",
    "Element",
    "Email",
    "Enabled",
    "EnrollmentStatus",
    "EntityId",
    "EntityType",
    "Entry",
    "EntryAttributes",
    "EntrypageId",
    "Entrypointfield",
    "ExpectedDepositDate",
    "ExpectedProcessingDateTime",
    "ExportFormat",
    "ExternalPaypointId",
    "ExternalProcessorInformation",
    "FaxNumber",
    "FeeAmount",
    "File",
    "FileContent",
    "FileContentFtype",
    "Finishtype",
    "ForceCustomerCreation",
    "FreightAmount",
    "Frequency",
    "FrequencyList",
    "Frequencynotification",
    "Gatewayfield",
    "GeneralEvents",
    "GooglePayData",
    "GooglePayMetadata",
    "GooglePayPaypointRegistrationData",
    "GooglePayStatusData",
    "GoogleWalletData",
    "HasVcardTransactions",
    "HeaderElement",
    "Highticketamt",
    "Holdername",
    "IdempotencyKey",
    "Identifierfields",
    "Idpaypoint",
    "Initiator",
    "Instrument",
    "InternalReferenceId",
    "InvoiceAmount",
    "InvoiceElement",
    "InvoiceNumber",
    "InvoiceType",
    "Invoicestatus",
    "IpAddress",
    "IsEnabled",
    "IsRoot",
    "IsSameDayAch",
    "IsSuccess",
    "ItemCommodityCode",
    "ItemDescription",
    "ItemProductCode",
    "ItemProductName",
    "ItemUnitofMeasure",
    "JobId",
    "JobStatus",
    "KeyValue",
    "KeyValueDuo",
    "LabelElement",
    "Language",
    "LastModified",
    "Legalname",
    "License",
    "Licensestate",
    "LineItem",
    "LineItemQueryRecord",
    "LinkData",
    "LinkRow",
    "LocationCode",
    "Maddress",
    "Maddress1",
    "Maskedaccount",
    "Mcc",
    "Mcity",
    "Mcountry",
    "MethodElement",
    "MethodElementSettings",
    "MethodElementSettingsApplePay",
    "MethodElementSettingsApplePayButtonStyle",
    "MethodElementSettingsApplePayButtonType",
    "MethodElementSettingsApplePayLanguage",
    "MethodQueryRecords",
    "MethodReferenceId",
    "Methodall",
    "Methodnotification",
    "MethodsList",
    "Mfa",
    "MfaData",
    "MfaMode",
    "MfaValidationCode",
    "Mstate",
    "Mzip",
    "NameUser",
    "NetAmountstring",
    "Netamountnullable",
    "NoteElement",
    "NotificationContent",
    "NotificationContentEventType",
    "NotificationContentFileFormat",
    "NotificationContentReportName",
    "NotificationId",
    "NotificationQueryRecord",
    "NotificationReportRequest",
    "NotificationReportRequestContent",
    "NotificationReportRequestContentFileFormat",
    "NotificationReportRequestContentReportName",
    "NotificationReportRequestFrequency",
    "NotificationReportRequestMethod",
    "NotificationStandardRequest",
    "NotificationStandardRequestContent",
    "NotificationStandardRequestContentEventType",
    "NotificationStandardRequestFrequency",
    "NotificationStandardRequestMethod",
    "OList",
    "OSection",
    "OdpSetup",
    "OdpSetupProcessingRegion",
    "Operation",
    "OptinStatus",
    "Order",
    "OrderId",
    "Orderdescription",
    "OrgData",
    "OrgParentId",
    "OrgParentName",
    "OrgScope",
    "OrgXScope",
    "Orgaddress",
    "OrganizationId",
    "OrganizationQueryRecord",
    "OrganizationQueryRecordServicesItem",
    "OrganizationUpdates",
    "Orgcity",
    "Orgcountry",
    "Orgentryname",
    "Orgid",
    "Orgidstring",
    "Orgname",
    "Orgstate",
    "Orgtimezone",
    "Orgtype",
    "Orgwebsite",
    "Orgzip",
    "OwnType",
    "OwnerEntityId",
    "OwnerEntityType",
    "Ownerid",
    "Owners",
    "OwnersSection",
    "Ownership",
    "Ownertype",
    "PSection",
    "PageContent",
    "PageElement",
    "PageIdentifier",
    "PageSetting",
    "PagelinkSetting",
    "Pagesize",
    "PairFiles",
    "PayCategory",
    "PayMethodAch",
    "PayMethodBodyAllFields",
    "PayMethodCloud",
    "PayMethodCredit",
    "PayMethodStoredMethod",
    "PayMethodStoredMethodMethod",
    "PayabliApiResponse",
    "PayabliApiResponse0",
    "PayabliApiResponse00",
    "PayabliApiResponse0000",
    "PayabliApiResponse00Responsedatanonobject",
    "PayabliApiResponse0ResponseData",
    "PayabliApiResponse6",
    "PayabliApiResponseCustomerQuery",
    "PayabliApiResponseError400",
    "PayabliApiResponseError400ResponseData",
    "PayabliApiResponseGeneric2Part",
    "PayabliApiResponseImport",
    "PayabliApiResponseImportResponseData",
    "PayabliApiResponseMfaBasic",
    "PayabliApiResponseNotifications",
    "PayabliApiResponseNotificationsResponseData",
    "PayabliApiResponsePaylinks",
    "PayabliApiResponsePaymethodDelete",
    "PayabliApiResponsePaymethodDeleteResponseData",
    "PayabliApiResponseTemplateId",
    "PayabliApiResponseUserMfa",
    "PayabliApiResponseVendors",
    "PayabliCredentials",
    "PayabliCredentialsPascal",
    "PayabliPages",
    "PayeeName",
    "PaylinkId",
    "PaymentCategories",
    "PaymentDetail",
    "PaymentDetailCredit",
    "PaymentIdString",
    "PaymentMethod",
    "PaymentMethodDomainApiResponse",
    "PaymentMethodDomainGeneralResponse",
    "PaymentMethodDomainId",
    "PaymentTransStatusDescription",
    "Paymentid",
    "PayorDataRequest",
    "PayorDataResponse",
    "PayorElement",
    "PayorFields",
    "PayorId",
    "PayoutAverageMonthlyVolume",
    "PayoutAverageTicketLimit",
    "PayoutCreditLimit",
    "PayoutGatewayConnector",
    "PayoutHighTicketAmount",
    "PayoutProgram",
    "PaypointData",
    "PaypointEntryConfig",
    "PaypointId",
    "PaypointName",
    "PaypointSummary",
    "Paypointstatus",
    "PciAttestation",
    "PendingFeeAmount",
    "PhoneNumber",
    "PoiDevice",
    "PolicyId",
    "PosCol",
    "PosRow",
    "ProcessingSection",
    "PurchaseOrder",
    "PushPayLinkRequest",
    "PushPayLinkRequestEmail",
    "PushPayLinkRequestSms",
    "PushPayLinkRequest_Email",
    "PushPayLinkRequest_Sms",
    "QueryBatchesOutResponse",
    "QueryBatchesOutResponseRecordsItem",
    "QueryBoardingAppsListResponse",
    "QueryBoardingLinksResponse",
    "QueryBoardingLinksResponseRecordsItem",
    "QueryCFeeTransaction",
    "QueryChargebacksResponse",
    "QueryChargebacksResponseRecordsItem",
    "QueryCustomerResponse",
    "QueryEntrypointResponse",
    "QueryEntrypointResponseRecordsItem",
    "QueryPaymentData",
    "QueryPayoutTransaction",
    "QueryPayoutTransactionRecordsItem",
    "QueryPayoutTransactionRecordsItemPaymentData",
    "QueryPayoutTransactionSummary",
    "QueryResponse",
    "QueryResponseData",
    "QueryResponseItems",
    "QueryResponseItemsRecordsItem",
    "QueryResponseNotificationReports",
    "QueryResponseNotificationReportsRecordsItem",
    "QueryResponseNotifications",
    "QueryResponseNotificationsRecordsItem",
    "QueryResponseSettlements",
    "QueryResponseSettlementsRecordsItem",
    "QueryResponseSettlementsSummary",
    "QueryResponseTransactions",
    "QueryResponseVendors",
    "QuerySubscriptionResponse",
    "QuerySummary",
    "QuerySummaryNoAmt",
    "QueryTransactionEvents",
    "QueryTransactionEventsEventData",
    "QueryTransactionPayorData",
    "QueryUserResponse",
    "ReadOnly",
    "ReceiptContent",
    "RecipientEmailNotification",
    "ReferenceName",
    "ReferenceTemplateId",
    "Referenceidtrans",
    "RefundDetail",
    "RefundId",
    "RemitEmail",
    "Remitaddress1",
    "Remitaddress2",
    "Remitcity",
    "Remitcountry",
    "Remitstate",
    "Remitzip",
    "RepCode",
    "RepName",
    "RepOffice",
    "ReplyToEmail",
    "Replyby",
    "RequiredElement",
    "ResponseText",
    "Responsecode",
    "Responsedata",
    "Responsedatanonobject",
    "ResultCode",
    "Resulttext",
    "Resumable",
    "RetrievalId",
    "ReturnedId",
    "RiskAction",
    "RiskActionCode",
    "RiskFlagged",
    "RiskFlaggedOn",
    "RiskReason",
    "RiskStatus",
    "RoomIdNotInUse",
    "RoutingAccount",
    "SSection",
    "SalesCode",
    "SalesSection",
    "SaveIfSuccess",
    "ScheduleDetail",
    "ScheduleId",
    "Sequence",
    "ServiceCost",
    "Services",
    "ServicesSection",
    "SettingElement",
    "SettingsQueryRecord",
    "SettlementStatus",
    "SettlementStatusPayout",
    "ShippingFromZip",
    "Shippingaddress",
    "Shippingaddressadditional",
    "Shippingcity",
    "Shippingcountry",
    "Shippingstate",
    "Shippingzip",
    "SignDate",
    "Signaturedata",
    "SignedDocumentReference",
    "SignerAcceptance",
    "SignerAddress1",
    "SignerCity",
    "SignerCountry",
    "SignerData",
    "SignerDataRequest",
    "SignerDob",
    "SignerName",
    "SignerPhone",
    "SignerSection",
    "SignerSsn",
    "SignerState",
    "SignerZip",
    "Signeraddress",
    "Source",
    "SplitFunding",
    "SplitFundingContent",
    "SplitFundingRefundContent",
    "StateNullable",
    "Statusnotification",
    "StoredMethodUsageType",
    "Storedmethodid",
    "SubFooter",
    "SubHeader",
    "Subdomain",
    "SubscriptionQueryRecords",
    "Subscriptionid",
    "SummaryCommodityCode",
    "SummaryOrg",
    "Target",
    "Tax",
    "Taxfillname",
    "TemplateAdditionalDataField",
    "TemplateAdditionalDataSection",
    "TemplateCode",
    "TemplateContent",
    "TemplateContentResponse",
    "TemplateData",
    "TemplateElement",
    "TemplateId",
    "TemplateName",
    "TemplateQueryRecord",
    "TemplateQueryResponse",
    "Terms",
    "TermsConditions",
    "Ticketamt",
    "TierItem",
    "TierItemPass",
    "Timezone",
    "Totalpages",
    "Totalrecords",
    "TransStatus",
    "TransactionOutQueryRecord",
    "TransactionQueryRecords",
    "TransactionTime",
    "Transfer",
    "TransferBankAccount",
    "TransferIdentifier",
    "TransferMessage",
    "TransferMessageProperties",
    "TransferQueryResponse",
    "TransferSummary",
    "TypeAccount",
    "UnderWritingMethod",
    "UnderwritingData",
    "UnderwritingDataResponse",
    "UserData",
    "UserQueryRecord",
    "UsrAccess",
    "UsrStatus",
    "VCardQueryResponse",
    "VCardRecord",
    "VCardSummary",
    "ValueTemplates",
    "VendorCheckNumber",
    "VendorData",
    "VendorDataResponse",
    "VendorDataResponsePaymentMethod",
    "VendorEin",
    "VendorName1",
    "VendorName2",
    "VendorNumber",
    "VendorOutData",
    "VendorPaymentMethod",
    "VendorPaymentMethodString",
    "VendorPhone",
    "VendorQueryRecord",
    "VendorResponseBillingData",
    "VendorResponseStoredMethod",
    "VendorResponseSummary",
    "VendorSummary",
    "Vendorid",
    "Vendorstatus",
    "Visible",
    "WalletCascade",
    "WalletIsEnabled",
    "Website",
    "Whencharged",
    "Whendelivered",
    "Whenprovided",
    "Whenrefunded",
    "Zip",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .accept_oauth import AcceptOauth
from .accept_register import AcceptRegister
from .builder_data import BuilderData
from .entry_attributes import EntryAttributes
from .file_content import FileContent
from .orgid import Orgid
from .page_identifier import PageIdentifier
from .recipient_email_notification import RecipientEmailNotification
from .reference_name import ReferenceName
from .reference_template_id import ReferenceTemplateId
from .resumable import Resumable


class BoardingLinkQueryRecord(UniversalBaseModel):
    accept_oauth: typing_extensions.Annotated[typing.Optional[AcceptOauth], FieldMetadata(alias="acceptOauth")] = None
    accept_register: typing_extensions.Annotated[
        typing.Optional[AcceptRegister], FieldMetadata(alias="acceptRegister")
    ] = None
    builder_data: typing_extensions.Annotated[typing.Optional[BuilderData], FieldMetadata(alias="builderData")] = None
    entry_attributes: typing_extensions.Annotated[
        typing.Optional[EntryAttributes], FieldMetadata(alias="entryAttributes")
    ] = None
    id: typing.Optional[int] = None
    logo: typing.Optional[FileContent] = pydantic.Field(default=None)
    """
    Object containing logo file.
    """

    org_id: typing_extensions.Annotated[typing.Optional[Orgid], FieldMetadata(alias="orgId")] = None
    page_identifier: typing_extensions.Annotated[
        typing.Optional[PageIdentifier], FieldMetadata(alias="pageIdentifier:")
    ] = None
    recipient_email_notification: typing_extensions.Annotated[
        typing.Optional[RecipientEmailNotification], FieldMetadata(alias="recipientEmailNotification")
    ] = None
    reference_name: typing_extensions.Annotated[
        typing.Optional[ReferenceName], FieldMetadata(alias="referenceName")
    ] = None
    reference_template_id: typing_extensions.Annotated[
        typing.Optional[ReferenceTemplateId], FieldMetadata(alias="referenceTemplateId")
    ] = None
    resumable: typing.Optional[Resumable] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .created_at import CreatedAt
from .customer_number_nullable import CustomerNumberNullable
from .customer_status import CustomerStatus
from .email import Email
from .identifierfields import Identifierfields
from .shippingaddress import Shippingaddress
from .shippingaddressadditional import Shippingaddressadditional
from .shippingcity import Shippingcity
from .shippingcountry import Shippingcountry
from .shippingstate import Shippingstate
from .shippingzip import Shippingzip
from .timezone import Timezone


class CustomerData(UniversalBaseModel):
    """
    Data about a single customer.
    """

    customer_number: typing_extensions.Annotated[
        typing.Optional[CustomerNumberNullable], FieldMetadata(alias="customerNumber")
    ] = None
    customer_username: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="customerUsername")] = (
        pydantic.Field(default=None)
    )
    """
    Customer username for customer portal
    """

    customer_psw: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="customerPsw")] = (
        pydantic.Field(default=None)
    )
    """
    Customer password for customer portal
    """

    customer_status: typing_extensions.Annotated[
        typing.Optional[CustomerStatus], FieldMetadata(alias="customerStatus")
    ] = None
    company: typing.Optional[str] = pydantic.Field(default=None)
    """
    Company name
    """

    firstname: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer first name
    """

    lastname: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer last name
    """

    phone: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer phone number
    """

    email: typing.Optional[Email] = pydantic.Field(default=None)
    """
    Customer email address.
    """

    address: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer address
    """

    address_1: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="address1")] = pydantic.Field(
        default=None
    )
    """
    Additional customer address
    """

    city: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer city
    """

    state: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer State
    """

    zip: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer postal code
    """

    country: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer country in ISO-3166-1 alpha 2 format. See https://en.wikipedia.org/wiki/ISO_3166-1 for reference.
    """

    shipping_address: typing_extensions.Annotated[
        typing.Optional[Shippingaddress], FieldMetadata(alias="shippingAddress")
    ] = None
    shipping_address_1: typing_extensions.Annotated[
        typing.Optional[Shippingaddressadditional], FieldMetadata(alias="shippingAddress1")
    ] = None
    shipping_city: typing_extensions.Annotated[typing.Optional[Shippingcity], FieldMetadata(alias="shippingCity")] = (
        None
    )
    shipping_state: typing_extensions.Annotated[
        typing.Optional[Shippingstate], FieldMetadata(alias="shippingState")
    ] = None
    shipping_zip: typing_extensions.Annotated[typing.Optional[Shippingzip], FieldMetadata(alias="shippingZip")] = None
    shipping_country: typing_extensions.Annotated[
        typing.Optional[Shippingcountry], FieldMetadata(alias="shippingCountry")
    ] = None
    balance: typing.Optional[float] = pydantic.Field(default=None)
    """
    Customer balance.
    """

    time_zone: typing_extensions.Annotated[typing.Optional[Timezone], FieldMetadata(alias="timeZone")] = None
    additional_fields: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[str]]], FieldMetadata(alias="additionalFields")
    ] = pydantic.Field(default=None)
    """
    Additional Custom fields in format "key":"value".
    """

    identifier_fields: typing_extensions.Annotated[
        typing.Optional[Identifierfields], FieldMetadata(alias="identifierFields")
    ] = None
    created_at: typing_extensions.Annotated[typing.Optional[CreatedAt], FieldMetadata(alias="createdAt")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .file_content import FileContent
from .orgaddress import Orgaddress
from .orgid import Orgid
from .orgname import Orgname
from .orgtype import Orgtype


class OrgData(UniversalBaseModel):
    id_org: typing_extensions.Annotated[typing.Optional[Orgid], FieldMetadata(alias="idOrg")] = None
    org_address: typing_extensions.Annotated[typing.Optional[Orgaddress], FieldMetadata(alias="orgAddress")] = None
    org_logo: typing_extensions.Annotated[typing.Optional[FileContent], FieldMetadata(alias="orgLogo")] = None
    org_name: typing_extensions.Annotated[typing.Optional[Orgname], FieldMetadata(alias="orgName")] = None
    org_status: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="orgStatus")] = pydantic.Field(
        default=None
    )
    """
    The paypoint's status. 
    
    Active - `1`
    
    Inactive - 0
    """

    org_type: typing_extensions.Annotated[typing.Optional[Orgtype], FieldMetadata(alias="orgType")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class ConvertToken(UniversalBaseModel):
    """
    Object containing the information needed to convert a temporary token to a permanent token.
    """

    method: str = pydantic.Field()
    """
    The type of payment method to tokenize. When converting a temp token to a permanent token, this should match the `method` set for the temporary token, either `ach` or `card`.
    """

    token_id: typing_extensions.Annotated[str, FieldMetadata(alias="tokenId")] = pydantic.Field()
    """
    A temporary stored token ID to be converted to permanent.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .page_identifier import PageIdentifier
from .pagesize import Pagesize


class QueryPayoutTransactionSummary(UniversalBaseModel):
    page_identifier: typing_extensions.Annotated[
        typing.Optional[PageIdentifier], FieldMetadata(alias="pageIdentifier")
    ] = None
    page_size: typing_extensions.Annotated[typing.Optional[Pagesize], FieldMetadata(alias="pageSize")] = None
    total_amount: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="totalAmount")] = None
    total_authorized: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalAuthorized")] = None
    total_authorized_amount: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="totalAuthorizedAmount")
    ] = None
    total_canceled: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalCanceled")] = None
    total_canceled_amount: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="totalCanceledAmount")
    ] = None
    total_captured: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalCaptured")] = None
    total_captured_amount: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="totalCapturedAmount")
    ] = None
    total_net_amount: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="totalNetAmount")] = None
    total_open: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalOpen")] = None
    total_open_amount: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="totalOpenAmount")] = (
        None
    )
    total_pages: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalPages")] = None
    total_paid: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalPaid")] = None
    total_paid_amount: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="totalPaidAmount")] = (
        None
    )
    total_on_hold: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalOnHold")] = (
        pydantic.Field(default=None)
    )
    """
    Total number of transactions that are currently on hold. 
    """

    total_on_hold_amount: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="totalOnHoldAmount")
    ] = pydantic.Field(default=None)
    """
    Total amount of transactions that are currently on hold. 
    """

    total_processing: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalProcessing")] = None
    total_processing_amount: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="totalProcessingAmount")
    ] = None
    total_records: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalRecords")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .account_number import AccountNumber
from .bank_account_function import BankAccountFunction
from .bank_account_holder_name import BankAccountHolderName
from .bank_account_holder_type import BankAccountHolderType
from .bank_name import BankName
from .bank_nickname import BankNickname
from .routing_account import RoutingAccount
from .type_account import TypeAccount


class Bank(UniversalBaseModel):
    """
    Object that contains bank account details.
    """

    id: typing.Optional[int] = pydantic.Field(default=None)
    """
    The Payabli-assigned internal identifier for the bank account.
    """

    account_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="accountId")] = pydantic.Field(
        default=None
    )
    """
    A user-defined internal identifier for the bank account. This allows you to specify which bank account should be used for payments in cases where multiple accounts are configured.
    """

    nickname: typing.Optional[BankNickname] = None
    bank_name: typing_extensions.Annotated[typing.Optional[BankName], FieldMetadata(alias="bankName")] = None
    routing_account: typing_extensions.Annotated[
        typing.Optional[RoutingAccount], FieldMetadata(alias="routingAccount")
    ] = None
    account_number: typing_extensions.Annotated[
        typing.Optional[AccountNumber], FieldMetadata(alias="accountNumber")
    ] = None
    type_account: typing_extensions.Annotated[typing.Optional[TypeAccount], FieldMetadata(alias="typeAccount")] = None
    bank_account_holder_name: typing_extensions.Annotated[
        typing.Optional[BankAccountHolderName], FieldMetadata(alias="bankAccountHolderName")
    ] = None
    bank_account_holder_type: typing_extensions.Annotated[
        typing.Optional[BankAccountHolderType], FieldMetadata(alias="bankAccountHolderType")
    ] = None
    bank_account_function: typing_extensions.Annotated[
        typing.Optional[BankAccountFunction], FieldMetadata(alias="bankAccountFunction")
    ] = None
    verified: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Bank account verification status. When `true`, the account has been verified to exist and be in good standing based on vendor checks or previous processing histories.
    """

    status: typing.Optional[int] = pydantic.Field(default=None)
    """
    Bank account status
    """

    services: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Array of services associated with this bank account
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...types.customer_summary_record import CustomerSummaryRecord
from ...types.dbaname import Dbaname
from ...types.external_paypoint_id import ExternalPaypointId
from ...types.legalname import Legalname
from ...types.method_query_records import MethodQueryRecords
from ...types.org_parent_name import OrgParentName
from ...types.page_identifier import PageIdentifier
from ...types.payor_data_request import PayorDataRequest
from ...types.subscription_query_records import SubscriptionQueryRecords


class GetMethodResponseResponseDataCustomersItem(PayorDataRequest):
    balance: typing.Optional[float] = pydantic.Field(default=None)
    """
    Customer's current balance
    """

    created: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Creation timestamp
    """

    customer_consent: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="customerConsent")
    ] = pydantic.Field(default=None)
    """
    Customer consent information
    """

    customer_status: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="customerStatus")] = (
        pydantic.Field(default=None)
    )
    """
    Status code for the customer
    """

    customer_summary: typing_extensions.Annotated[
        typing.Optional[CustomerSummaryRecord], FieldMetadata(alias="customerSummary")
    ] = None
    customer_username: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="customerUsername")] = (
        pydantic.Field(default=None)
    )
    """
    Username of the customer
    """

    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId], FieldMetadata(alias="externalPaypointID")
    ] = None
    last_updated: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="lastUpdated")] = (
        pydantic.Field(default=None)
    )
    """
    Last update timestamp
    """

    mfa: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Multi-factor authentication status
    """

    mfa_mode: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="mfaMode")] = pydantic.Field(
        default=None
    )
    """
    MFA mode setting
    """

    pageindentifier: typing.Optional[PageIdentifier] = None
    parent_org_id: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="parentOrgId")] = (
        pydantic.Field(default=None)
    )
    """
    Parent organization ID
    """

    parent_org_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="parentOrgName")
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[typing.Optional[Dbaname], FieldMetadata(alias="paypointDbaname")] = (
        None
    )
    paypoint_entryname: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="paypointEntryname")] = (
        pydantic.Field(default=None)
    )
    """
    The paypoint entryname the customer is associated with
    """

    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[Legalname], FieldMetadata(alias="paypointLegalname")
    ] = None
    sn_data: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="snData")
    ] = pydantic.Field(default=None)
    """
    Social network data
    """

    sn_identifier: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="snIdentifier")] = (
        pydantic.Field(default=None)
    )
    """
    Social network identifier
    """

    sn_provider: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="snProvider")] = pydantic.Field(
        default=None
    )
    """
    Social network provider
    """

    stored_methods: typing_extensions.Annotated[
        typing.Optional[typing.List[MethodQueryRecords]], FieldMetadata(alias="storedMethods")
    ] = pydantic.Field(default=None)
    """
    List of payment methods associated to the customer
    """

    subscriptions: typing.Optional[typing.List[SubscriptionQueryRecords]] = pydantic.Field(default=None)
    """
    List of subscriptions associated to the customer
    """

    time_zone: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="timeZone")] = pydantic.Field(
        default=None
    )
    """
    Customer's timezone
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .frequency import Frequency


class ScheduleDetail(UniversalBaseModel):
    end_date: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="endDate")] = pydantic.Field(
        default=None
    )
    """
    Subscription end date in any of the accepted formats: YYYY-MM-DD, MM/DD/YYYY or the value `untilcancelled` to indicate a scheduled payment with infinite cycle.
    """

    frequency: typing.Optional[Frequency] = pydantic.Field(default=None)
    """
    Frequency of the subscription.
    """

    plan_id: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="planId")] = pydantic.Field(
        default=None
    )
    """
    This field is for future development, leave null. Identifier of subscription plan applied in the scheduled payment/subscription.
    """

    start_date: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="startDate")] = pydantic.Field(
        default=None
    )
    """
    Subscription start date in any of the accepted formats: YYYY-MM-DD, MM/DD/YYYY. This must be a future date.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        BatchDetailResponseRecord,
        BatchDetailResponseSummary,
        LimitRecord,
        ListOrganizationsResponse,
        QueryBatchesDetailResponse,
        QueryBatchesResponse,
        QueryBatchesResponseRecordsItem,
        QueryBatchesTransfer,
        QueryTransferDetailResponse,
        QueryTransferResponse,
        QueryTransferSummary,
        TransferDetailRecord,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "BatchDetailResponseRecord": ".types",
    "BatchDetailResponseSummary": ".types",
    "LimitRecord": ".types",
    "ListOrganizationsResponse": ".types",
    "QueryBatchesDetailResponse": ".types",
    "QueryBatchesResponse": ".types",
    "QueryBatchesResponseRecordsItem": ".types",
    "QueryBatchesTransfer": ".types",
    "QueryTransferDetailResponse": ".types",
    "QueryTransferResponse": ".types",
    "QueryTransferSummary": ".types",
    "TransferDetailRecord": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BatchDetailResponseRecord",
    "BatchDetailResponseSummary",
    "LimitRecord",
    "ListOrganizationsResponse",
    "QueryBatchesDetailResponse",
    "QueryBatchesResponse",
    "QueryBatchesResponseRecordsItem",
    "QueryBatchesTransfer",
    "QueryTransferDetailResponse",
    "QueryTransferResponse",
    "QueryTransferSummary",
    "TransferDetailRecord",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .accountexp import Accountexp
from .accountid import Accountid
from .accounttype import Accounttype
from .accountzip import Accountzip
from .bin_data import BinData
from .holdername import Holdername
from .initiator import Initiator
from .maskedaccount import Maskedaccount
from .orderdescription import Orderdescription
from .payment_detail import PaymentDetail
from .payout_gateway_connector import PayoutGatewayConnector
from .sequence import Sequence
from .stored_method_usage_type import StoredMethodUsageType
from .storedmethodid import Storedmethodid


class QueryPayoutTransactionRecordsItemPaymentData(UniversalBaseModel):
    account_exp: typing_extensions.Annotated[typing.Optional[Accountexp], FieldMetadata(alias="AccountExp")] = None
    account_id: typing_extensions.Annotated[typing.Optional[Accountid], FieldMetadata(alias="accountId")] = None
    account_type: typing_extensions.Annotated[typing.Optional[Accounttype], FieldMetadata(alias="AccountType")] = None
    account_zip: typing_extensions.Annotated[typing.Optional[Accountzip], FieldMetadata(alias="AccountZip")] = None
    bank_account: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="bankAccount")] = None
    bin_data: typing_extensions.Annotated[typing.Optional[BinData], FieldMetadata(alias="binData")] = None
    cloud_signature_data: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="cloudSignatureData")
    ] = None
    cloud_signature_format: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="cloudSignatureFormat")
    ] = None
    gateway_connector: typing_extensions.Annotated[
        typing.Optional[PayoutGatewayConnector], FieldMetadata(alias="gatewayConnector")
    ] = None
    holder_name: typing_extensions.Annotated[typing.Optional[Holdername], FieldMetadata(alias="HolderName")] = (
        pydantic.Field(default=None)
    )
    """
    Card or bank account holder name.
    """

    initiator: typing_extensions.Annotated[typing.Optional[Initiator], FieldMetadata(alias="Initiator")] = None
    masked_account: typing_extensions.Annotated[
        typing.Optional[Maskedaccount], FieldMetadata(alias="MaskedAccount")
    ] = None
    order_description: typing_extensions.Annotated[
        typing.Optional[Orderdescription], FieldMetadata(alias="orderDescription")
    ] = None
    payment_details: typing_extensions.Annotated[
        typing.Optional[PaymentDetail], FieldMetadata(alias="paymentDetails")
    ] = None
    payor_data: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="payorData")] = None
    sequence: typing_extensions.Annotated[typing.Optional[Sequence], FieldMetadata(alias="Sequence")] = None
    stored_id: typing_extensions.Annotated[typing.Optional[Storedmethodid], FieldMetadata(alias="StoredId")] = (
        pydantic.Field(default=None)
    )
    """
    Identifier of stored payment method used in transaction.
    """

    stored_method_usage_type: typing_extensions.Annotated[
        typing.Optional[StoredMethodUsageType], FieldMetadata(alias="StoredMethodUsageType")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .datetime_nullable import DatetimeNullable
from .email import Email


class BillQueryRecord2BillApprovalsItem(UniversalBaseModel):
    approved: typing.Optional[int] = pydantic.Field(default=None)
    """
    Indicates whether the bill has been approved. `0` is false, and `1` is true.
    """

    approved_time: typing_extensions.Annotated[
        typing.Optional[DatetimeNullable], FieldMetadata(alias="approvedTime")
    ] = pydantic.Field(default=None)
    """
    Timestamp of when the approval was made, in UTC.
    """

    comments: typing.Optional[str] = pydantic.Field(default=None)
    """
    Additional comments on the approval.
    """

    email: typing.Optional[Email] = pydantic.Field(default=None)
    """
    The approving user's email address.
    """

    id: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="Id")] = pydantic.Field(default=None)
    """
    The approving user's ID.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .a_section import ASection
from .b_section import BSection
from .d_section import DSection
from .o_section import OSection
from .p_section import PSection
from .s_section import SSection


class BuilderData(UniversalBaseModel):
    services: typing.Optional[SSection] = None
    attributes: typing.Optional[ASection] = None
    banking: typing.Optional[DSection] = None
    business: typing.Optional[BSection] = None
    owners: typing.Optional[OSection] = None
    processing: typing.Optional[PSection] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class StatBasicQueryRecord(UniversalBaseModel):
    stat_x: typing_extensions.Annotated[str, FieldMetadata(alias="statX")] = pydantic.Field()
    """
    Statistical grouping identifier
    """

    in_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="inTransactions")] = pydantic.Field()
    """
    Number of incoming transactions
    """

    in_transactions_volume: typing_extensions.Annotated[float, FieldMetadata(alias="inTransactionsVolume")] = (
        pydantic.Field()
    )
    """
    Volume of incoming transactions
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class OcrVendorBillingData(UniversalBaseModel):
    id: typing.Optional[int] = None
    bank_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="bankName")] = None
    routing_account: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="routingAccount")] = None
    account_number: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="accountNumber")] = None
    type_account: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="typeAccount")] = None
    bank_account_holder_name: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="bankAccountHolderName")
    ] = None
    bank_account_holder_type: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="bankAccountHolderType")
    ] = None
    bank_account_function: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="bankAccountFunction")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .additional_data_string import AdditionalDataString
from .billing_zip import BillingZip
from .customer_id import CustomerId
from .customer_number_nullable import CustomerNumberNullable
from .customer_status import CustomerStatus
from .email import Email
from .shippingaddress import Shippingaddress
from .shippingaddressadditional import Shippingaddressadditional
from .shippingcity import Shippingcity
from .shippingcountry import Shippingcountry
from .shippingstate import Shippingstate
from .shippingzip import Shippingzip


class QueryTransactionPayorData(UniversalBaseModel):
    identifiers: typing_extensions.Annotated[
        typing.Optional[typing.List[typing.Optional[typing.Any]]], FieldMetadata(alias="Identifiers")
    ] = pydantic.Field(default=None)
    """
    Array of field names to be used as identifiers.
    """

    first_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="FirstName")] = pydantic.Field(
        default=None
    )
    """
    Customer/Payor first name.
    """

    last_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="LastName")] = pydantic.Field(
        default=None
    )
    """
    Customer/Payor last name.
    """

    company_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="CompanyName")] = (
        pydantic.Field(default=None)
    )
    """
    Customer's company name.
    """

    billing_address_1: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BillingAddress1")] = (
        pydantic.Field(default=None)
    )
    """
    Customer's billing address.
    """

    billing_address_2: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BillingAddress2")] = (
        pydantic.Field(default=None)
    )
    """
    Additional line for Customer's billing address.
    """

    billing_city: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BillingCity")] = (
        pydantic.Field(default=None)
    )
    """
    Customer's billing city.
    """

    billing_state: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BillingState")] = (
        pydantic.Field(default=None)
    )
    """
    Customer's billing state. Must be 2-letter state code for address in US.
    """

    billing_zip: typing_extensions.Annotated[typing.Optional[BillingZip], FieldMetadata(alias="BillingZip")] = (
        pydantic.Field(default=None)
    )
    """
    Customer's billing ZIP code.
    """

    billing_country: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BillingCountry")] = (
        pydantic.Field(default=None)
    )
    """
    Customer's billing country.
    """

    billing_phone: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BillingPhone")] = (
        pydantic.Field(default=None)
    )
    """
    Customer's phone number.
    """

    billing_email: typing_extensions.Annotated[typing.Optional[Email], FieldMetadata(alias="BillingEmail")] = (
        pydantic.Field(default=None)
    )
    """
    Customer's email address.
    """

    customer_number: typing_extensions.Annotated[
        typing.Optional[CustomerNumberNullable], FieldMetadata(alias="CustomerNumber")
    ] = None
    shipping_address_1: typing_extensions.Annotated[
        typing.Optional[Shippingaddress], FieldMetadata(alias="ShippingAddress1")
    ] = None
    shipping_address_2: typing_extensions.Annotated[
        typing.Optional[Shippingaddressadditional], FieldMetadata(alias="ShippingAddress2")
    ] = None
    shipping_city: typing_extensions.Annotated[typing.Optional[Shippingcity], FieldMetadata(alias="ShippingCity")] = (
        None
    )
    shipping_state: typing_extensions.Annotated[
        typing.Optional[Shippingstate], FieldMetadata(alias="ShippingState")
    ] = None
    shipping_zip: typing_extensions.Annotated[typing.Optional[Shippingzip], FieldMetadata(alias="ShippingZip")] = None
    shipping_country: typing_extensions.Annotated[
        typing.Optional[Shippingcountry], FieldMetadata(alias="ShippingCountry")
    ] = None
    customer_id: typing_extensions.Annotated[typing.Optional[CustomerId], FieldMetadata(alias="customerId")] = None
    customer_status: typing_extensions.Annotated[
        typing.Optional[CustomerStatus], FieldMetadata(alias="customerStatus")
    ] = None
    additional_data: typing_extensions.Annotated[
        typing.Optional[AdditionalDataString], FieldMetadata(alias="AdditionalData")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .additional_data_string import AdditionalDataString
from .attestation_date import AttestationDate
from .email import Email
from .pci_attestation import PciAttestation
from .sign_date import SignDate
from .signer_acceptance import SignerAcceptance
from .signer_address_1 import SignerAddress1
from .signer_city import SignerCity
from .signer_country import SignerCountry
from .signer_dob import SignerDob
from .signer_name import SignerName
from .signer_phone import SignerPhone
from .signer_ssn import SignerSsn
from .signer_state import SignerState
from .signer_zip import SignerZip
from .signeraddress import Signeraddress


class SignerData(UniversalBaseModel):
    """
    Information about the application's signer.

    Examples
    --------
    from payabli import SignerData

    SignerData(
        address="33 North St",
        address_1="STE 900",
        city="Bristol",
        country="US",
        dob="01/01/1976",
        email="test@email.com",
        name="John Smith",
        phone="555888111",
        ssn="123456789",
        state="TN",
        zip="55555",
        pci_attestation=True,
        signed_document_reference="https://example.com/signed-document.pdf",
        attestation_date="04/20/2025",
        sign_date="04/20/2025",
        additional_data='{"deviceId":"499585-389fj484-3jcj8hj3","session":"fifji4-fiu443-fn4843","timeWithCompany":"6 Years"}',
    )
    """

    signer_uuid: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="signerUuid")] = pydantic.Field(
        default=None
    )
    """
    The signer's ID. This is automatically generated by Payabli.
    """

    name: typing.Optional[SignerName] = None
    ssn: typing.Optional[SignerSsn] = None
    dob: typing.Optional[SignerDob] = None
    phone: typing.Optional[SignerPhone] = None
    email: typing.Optional[Email] = pydantic.Field(default=None)
    """
    The signer's email address.
    """

    address: typing.Optional[Signeraddress] = None
    address_1: typing_extensions.Annotated[typing.Optional[SignerAddress1], FieldMetadata(alias="address1")] = None
    city: typing.Optional[SignerCity] = None
    state: typing.Optional[SignerState] = None
    zip: typing.Optional[SignerZip] = None
    country: typing.Optional[SignerCountry] = None
    acceptance: typing.Optional[SignerAcceptance] = None
    signed_document_reference: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="signedDocumentReference")
    ] = pydantic.Field(default=None)
    """
    Reference to the signed document.
    """

    pci_attestation: typing_extensions.Annotated[
        typing.Optional[PciAttestation], FieldMetadata(alias="pciAttestation")
    ] = None
    attestation_date: typing_extensions.Annotated[
        typing.Optional[AttestationDate], FieldMetadata(alias="attestationDate")
    ] = None
    sign_date: typing_extensions.Annotated[typing.Optional[SignDate], FieldMetadata(alias="signDate")] = None
    additional_data: typing_extensions.Annotated[
        typing.Optional[AdditionalDataString], FieldMetadata(alias="additionalData")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .query_transaction_events_event_data import QueryTransactionEventsEventData


class QueryTransactionEvents(UniversalBaseModel):
    event_data: typing_extensions.Annotated[
        typing.Optional[QueryTransactionEventsEventData], FieldMetadata(alias="EventData")
    ] = pydantic.Field(default=None)
    """
    Any data associated to the event received from processor. Contents vary by event type.
    """

    event_time: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="EventTime")] = (
        pydantic.Field(default=None)
    )
    """
    Date and time of event.
    """

    trans_event: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="TransEvent")] = pydantic.Field(
        default=None
    )
    """
    Event descriptor. See [TransEvent Reference](/developers/references/transevents) for more details.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .apple_pay_data import ApplePayData
from .cascade_job_details import CascadeJobDetails
from .created_at import CreatedAt
from .domain_name import DomainName
from .entity_id import EntityId
from .entity_type import EntityType
from .google_pay_data import GooglePayData
from .last_modified import LastModified
from .owner_entity_id import OwnerEntityId
from .owner_entity_type import OwnerEntityType
from .payment_method_domain_id import PaymentMethodDomainId


class PaymentMethodDomainApiResponse(UniversalBaseModel):
    """
    Data related to the payment method domain.
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The record type. For payment method domains, this is always `PaymentMethodDomain`.
    """

    apple_pay: typing_extensions.Annotated[ApplePayData, FieldMetadata(alias="applePay")]
    google_pay: typing_extensions.Annotated[GooglePayData, FieldMetadata(alias="googlePay")]
    cascades: typing.Optional[typing.List[CascadeJobDetails]] = pydantic.Field(default=None)
    """
    Data about the domain's cascade status.
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]
    domain_name: typing_extensions.Annotated[DomainName, FieldMetadata(alias="domainName")]
    entity_id: typing_extensions.Annotated[EntityId, FieldMetadata(alias="entityId")]
    entity_type: typing_extensions.Annotated[EntityType, FieldMetadata(alias="entityType")]
    id: PaymentMethodDomainId
    owner_entity_id: typing_extensions.Annotated[OwnerEntityId, FieldMetadata(alias="ownerEntityId")]
    owner_entity_type: typing_extensions.Annotated[OwnerEntityType, FieldMetadata(alias="ownerEntityType")]
    updated_at: typing_extensions.Annotated[LastModified, FieldMetadata(alias="updatedAt")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.cascade import Cascade
from ..types.configure_apple_pay_organization_api_response import ConfigureApplePayOrganizationApiResponse
from ..types.configure_apple_paypoint_api_response import ConfigureApplePaypointApiResponse
from ..types.configure_google_paypoint_api_response import ConfigureGooglePaypointApiResponse
from ..types.entry import Entry
from ..types.is_enabled import IsEnabled
from ..types.organization_id import OrganizationId
from .raw_client import AsyncRawWalletClient, RawWalletClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class WalletClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawWalletClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawWalletClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawWalletClient
        """
        return self._raw_client

    def configure_apple_pay_organization(
        self,
        *,
        cascade: typing.Optional[Cascade] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        org_id: typing.Optional[OrganizationId] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConfigureApplePayOrganizationApiResponse:
        """
        Configure and activate Apple Pay for a Payabli organization

        Parameters
        ----------
        cascade : typing.Optional[Cascade]

        is_enabled : typing.Optional[IsEnabled]

        org_id : typing.Optional[OrganizationId]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConfigureApplePayOrganizationApiResponse
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.wallet.configure_apple_pay_organization(
            cascade=True,
            is_enabled=True,
            org_id=901,
        )
        """
        _response = self._raw_client.configure_apple_pay_organization(
            cascade=cascade, is_enabled=is_enabled, org_id=org_id, request_options=request_options
        )
        return _response.data

    def configure_apple_pay_paypoint(
        self,
        *,
        entry: typing.Optional[Entry] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConfigureApplePaypointApiResponse:
        """
        Configure and activate Apple Pay for a Payabli paypoint

        Parameters
        ----------
        entry : typing.Optional[Entry]

        is_enabled : typing.Optional[IsEnabled]
            When `true`, Apple Pay is enabled.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConfigureApplePaypointApiResponse
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.wallet.configure_apple_pay_paypoint(
            entry="8cfec329267",
            is_enabled=True,
        )
        """
        _response = self._raw_client.configure_apple_pay_paypoint(
            entry=entry, is_enabled=is_enabled, request_options=request_options
        )
        return _response.data

    def configure_google_pay_organization(
        self,
        *,
        cascade: typing.Optional[Cascade] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        org_id: typing.Optional[OrganizationId] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConfigureApplePayOrganizationApiResponse:
        """
        Configure and activate Google Pay for a Payabli organization

        Parameters
        ----------
        cascade : typing.Optional[Cascade]

        is_enabled : typing.Optional[IsEnabled]

        org_id : typing.Optional[OrganizationId]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConfigureApplePayOrganizationApiResponse
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.wallet.configure_google_pay_organization(
            cascade=True,
            is_enabled=True,
            org_id=901,
        )
        """
        _response = self._raw_client.configure_google_pay_organization(
            cascade=cascade, is_enabled=is_enabled, org_id=org_id, request_options=request_options
        )
        return _response.data

    def configure_google_pay_paypoint(
        self,
        *,
        entry: typing.Optional[Entry] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConfigureGooglePaypointApiResponse:
        """
        Configure and activate Google Pay for a Payabli paypoint

        Parameters
        ----------
        entry : typing.Optional[Entry]

        is_enabled : typing.Optional[IsEnabled]
            When `true`, Google Pay is enabled.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConfigureGooglePaypointApiResponse
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.wallet.configure_google_pay_paypoint(
            entry="8cfec329267",
            is_enabled=True,
        )
        """
        _response = self._raw_client.configure_google_pay_paypoint(
            entry=entry, is_enabled=is_enabled, request_options=request_options
        )
        return _response.data


class AsyncWalletClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawWalletClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawWalletClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawWalletClient
        """
        return self._raw_client

    async def configure_apple_pay_organization(
        self,
        *,
        cascade: typing.Optional[Cascade] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        org_id: typing.Optional[OrganizationId] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConfigureApplePayOrganizationApiResponse:
        """
        Configure and activate Apple Pay for a Payabli organization

        Parameters
        ----------
        cascade : typing.Optional[Cascade]

        is_enabled : typing.Optional[IsEnabled]

        org_id : typing.Optional[OrganizationId]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConfigureApplePayOrganizationApiResponse
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.wallet.configure_apple_pay_organization(
                cascade=True,
                is_enabled=True,
                org_id=901,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.configure_apple_pay_organization(
            cascade=cascade, is_enabled=is_enabled, org_id=org_id, request_options=request_options
        )
        return _response.data

    async def configure_apple_pay_paypoint(
        self,
        *,
        entry: typing.Optional[Entry] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConfigureApplePaypointApiResponse:
        """
        Configure and activate Apple Pay for a Payabli paypoint

        Parameters
        ----------
        entry : typing.Optional[Entry]

        is_enabled : typing.Optional[IsEnabled]
            When `true`, Apple Pay is enabled.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConfigureApplePaypointApiResponse
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.wallet.configure_apple_pay_paypoint(
                entry="8cfec329267",
                is_enabled=True,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.configure_apple_pay_paypoint(
            entry=entry, is_enabled=is_enabled, request_options=request_options
        )
        return _response.data

    async def configure_google_pay_organization(
        self,
        *,
        cascade: typing.Optional[Cascade] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        org_id: typing.Optional[OrganizationId] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConfigureApplePayOrganizationApiResponse:
        """
        Configure and activate Google Pay for a Payabli organization

        Parameters
        ----------
        cascade : typing.Optional[Cascade]

        is_enabled : typing.Optional[IsEnabled]

        org_id : typing.Optional[OrganizationId]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConfigureApplePayOrganizationApiResponse
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.wallet.configure_google_pay_organization(
                cascade=True,
                is_enabled=True,
                org_id=901,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.configure_google_pay_organization(
            cascade=cascade, is_enabled=is_enabled, org_id=org_id, request_options=request_options
        )
        return _response.data

    async def configure_google_pay_paypoint(
        self,
        *,
        entry: typing.Optional[Entry] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConfigureGooglePaypointApiResponse:
        """
        Configure and activate Google Pay for a Payabli paypoint

        Parameters
        ----------
        entry : typing.Optional[Entry]

        is_enabled : typing.Optional[IsEnabled]
            When `true`, Google Pay is enabled.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConfigureGooglePaypointApiResponse
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.wallet.configure_google_pay_paypoint(
                entry="8cfec329267",
                is_enabled=True,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.configure_google_pay_paypoint(
            entry=entry, is_enabled=is_enabled, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .notification_standard_request_content import NotificationStandardRequestContent
from .notification_standard_request_frequency import NotificationStandardRequestFrequency
from .notification_standard_request_method import NotificationStandardRequestMethod
from .ownerid import Ownerid
from .ownertype import Ownertype
from .statusnotification import Statusnotification


class NotificationStandardRequest(UniversalBaseModel):
    """
    Information about the standard notification configuration (email, sms, web).
    """

    content: typing.Optional[NotificationStandardRequestContent] = None
    frequency: NotificationStandardRequestFrequency
    method: NotificationStandardRequestMethod = pydantic.Field()
    """
    Get near-instant notifications via email, SMS, or webhooks for important events like new payment disputes, merchant activations, fraud alerts, approved transactions, settlement history, vendor payouts, and more. Use webhooks with notifications to get real-time updates and automate operations based on key those key events. See [Notifications](/developers/developer-guides/notifications-and-webhooks-overview#notifications) for more.
    """

    owner_id: typing_extensions.Annotated[typing.Optional[Ownerid], FieldMetadata(alias="ownerId")] = None
    owner_type: typing_extensions.Annotated[Ownertype, FieldMetadata(alias="ownerType")]
    status: typing.Optional[Statusnotification] = None
    target: str = pydantic.Field()
    """
    Specify the notification target.
    
    - For method=email the expected value is a list of email addresses separated by semicolon.
    - For method=sms the expected value is a list of phone numbers separated by semicolon.
    - For method=web the expected value is a valid and complete URL. Webhooks support only standard HTTP ports: 80, 443, 8080, or 4443.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
